@@ -9,7 +9,8 @@ approach to loading dynamic link libraries.
 
 # Example
 ```no_run
-use dlopen2::raw::Library;
+extern crate dlopen;
+use dlopen::raw::Library;
 fn main(){
     let lib = Library::open("libexample.so").unwrap();
     let fun_add_one: unsafe extern "C" fn(i32)->i32 = unsafe{lib.symbol("add_one")}.unwrap();
@@ -21,14 +22,16 @@ fn main(){
 ```
 */
 
+
+
 //!
 
 mod common;
-#[cfg(test)]
-mod tests;
 #[cfg(unix)]
 mod unix;
 #[cfg(windows)]
 mod windows;
+#[cfg(test)]
+mod tests;
 
-pub use self::common::{AddressInfo, AddressInfoObtainer, Library, OverlappingSymbol};
+pub use self::common::{Library, AddressInfo, OverlappingSymbol, AddressInfoObtainer};
