@@ -1,7 +1,7 @@
-use super::super::err::Error;
-use super::from_raw::{FromRawResult, RawResult};
 use std::marker::PhantomData;
 use std::ops::Deref;
+use super::from_raw::{FromRawResult, RawResult};
+use super::super::err::Error;
 
 ///Safe wrapper around mutable pointer.
 ///
@@ -15,7 +15,7 @@ pub struct PtrOrNullMut<'lib, T: 'lib> {
 impl<'lib, T> PtrOrNullMut<'lib, T> {
     pub fn new(pointer: *mut T) -> PtrOrNullMut<'lib, T> {
         PtrOrNullMut {
-            pointer,
+            pointer: pointer,
             pd: PhantomData,
         }
     }
