@@ -1,9 +1,9 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[doc = "*Required features: `\"Devices_Custom\"`*"]
+#[doc = "*Required features: 'Devices_Custom'*"]
 #[repr(transparent)]
 pub struct CustomDevice(::windows::core::IUnknown);
 impl CustomDevice {
-    #[doc = "*Required features: `\"Devices_Custom\"`, `\"Storage_Streams\"`*"]
+    #[doc = "*Required features: 'Devices_Custom', 'Storage_Streams'*"]
     #[cfg(feature = "Storage_Streams")]
     pub fn InputStream(&self) -> ::windows::core::Result<super::super::Storage::Streams::IInputStream> {
         let this = self;
@@ -12,7 +12,7 @@ impl CustomDevice {
             (::windows::core::Interface::vtable(this).InputStream)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Storage::Streams::IInputStream>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`, `\"Storage_Streams\"`*"]
+    #[doc = "*Required features: 'Devices_Custom', 'Storage_Streams'*"]
     #[cfg(feature = "Storage_Streams")]
     pub fn OutputStream(&self) -> ::windows::core::Result<super::super::Storage::Streams::IOutputStream> {
         let this = self;
@@ -21,7 +21,7 @@ impl CustomDevice {
             (::windows::core::Interface::vtable(this).OutputStream)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::Storage::Streams::IOutputStream>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`, `\"Foundation\"`, `\"Storage_Streams\"`*"]
+    #[doc = "*Required features: 'Devices_Custom', 'Foundation', 'Storage_Streams'*"]
     #[cfg(all(feature = "Foundation", feature = "Storage_Streams"))]
     pub fn SendIOControlAsync<'a, Param0: ::windows::core::IntoParam<'a, IIOControlCode>, Param1: ::windows::core::IntoParam<'a, super::super::Storage::Streams::IBuffer>, Param2: ::windows::core::IntoParam<'a, super::super::Storage::Streams::IBuffer>>(&self, iocontrolcode: Param0, inputbuffer: Param1, outputbuffer: Param2) -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<u32>> {
         let this = self;
@@ -30,7 +30,7 @@ impl CustomDevice {
             (::windows::core::Interface::vtable(this).SendIOControlAsync)(::core::mem::transmute_copy(this), iocontrolcode.into_param().abi(), inputbuffer.into_param().abi(), outputbuffer.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::IAsyncOperation<u32>>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`, `\"Foundation\"`, `\"Storage_Streams\"`*"]
+    #[doc = "*Required features: 'Devices_Custom', 'Foundation', 'Storage_Streams'*"]
     #[cfg(all(feature = "Foundation", feature = "Storage_Streams"))]
     pub fn TrySendIOControlAsync<'a, Param0: ::windows::core::IntoParam<'a, IIOControlCode>, Param1: ::windows::core::IntoParam<'a, super::super::Storage::Streams::IBuffer>, Param2: ::windows::core::IntoParam<'a, super::super::Storage::Streams::IBuffer>>(&self, iocontrolcode: Param0, inputbuffer: Param1, outputbuffer: Param2) -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<bool>> {
         let this = self;
@@ -39,14 +39,14 @@ impl CustomDevice {
             (::windows::core::Interface::vtable(this).TrySendIOControlAsync)(::core::mem::transmute_copy(this), iocontrolcode.into_param().abi(), inputbuffer.into_param().abi(), outputbuffer.into_param().abi(), &mut result__).from_abi::<super::super::Foundation::IAsyncOperation<bool>>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn GetDeviceSelector<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::GUID>>(classguid: Param0) -> ::windows::core::Result<::windows::core::HSTRING> {
         Self::ICustomDeviceStatics(|this| unsafe {
             let mut result__: ::core::mem::ManuallyDrop<::windows::core::HSTRING> = ::core::mem::zeroed();
             (::windows::core::Interface::vtable(this).GetDeviceSelector)(::core::mem::transmute_copy(this), classguid.into_param().abi(), &mut result__).from_abi::<::windows::core::HSTRING>(result__)
         })
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'Devices_Custom', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn FromIdAsync<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::HSTRING>>(deviceid: Param0, desiredaccess: DeviceAccessMode, sharingmode: DeviceSharingMode) -> ::windows::core::Result<super::super::Foundation::IAsyncOperation<CustomDevice>> {
         Self::ICustomDeviceStatics(|this| unsafe {
@@ -78,10 +78,6 @@ impl ::core::fmt::Debug for CustomDevice {
 }
 unsafe impl ::windows::core::RuntimeType for CustomDevice {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Devices.Custom.CustomDevice;{dd30251f-c48b-43bd-bcb1-dec88f15143e})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for CustomDevice {
     type Vtable = ICustomDevice_Vtbl;
@@ -105,7 +101,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for CustomDev
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a CustomDevice {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &CustomDevice {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -125,14 +121,14 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for Custo
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a CustomDevice {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &CustomDevice {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for CustomDevice {}
 unsafe impl ::core::marker::Sync for CustomDevice {}
-#[doc = "*Required features: `\"Devices_Custom\"`*"]
+#[doc = "*Required features: 'Devices_Custom'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct DeviceAccessMode(pub i32);
@@ -162,12 +158,11 @@ impl ::core::fmt::Debug for DeviceAccessMode {
 }
 unsafe impl ::windows::core::RuntimeType for DeviceAccessMode {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.Custom.DeviceAccessMode;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Devices_Custom\"`*"]
+impl ::windows::core::DefaultType for DeviceAccessMode {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Devices_Custom'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct DeviceSharingMode(pub i32);
@@ -196,10 +191,9 @@ impl ::core::fmt::Debug for DeviceSharingMode {
 }
 unsafe impl ::windows::core::RuntimeType for DeviceSharingMode {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.Custom.DeviceSharingMode;i4)");
+}
+impl ::windows::core::DefaultType for DeviceSharingMode {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 #[doc(hidden)]
 #[repr(transparent)]
@@ -246,11 +240,11 @@ pub struct ICustomDeviceStatics_Vtbl {
     #[cfg(not(feature = "Foundation"))]
     FromIdAsync: usize,
 }
-#[doc = "*Required features: `\"Devices_Custom\"`*"]
+#[doc = "*Required features: 'Devices_Custom'*"]
 #[repr(transparent)]
 pub struct IIOControlCode(::windows::core::IUnknown);
 impl IIOControlCode {
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn AccessMode(&self) -> ::windows::core::Result<IOControlAccessMode> {
         let this = self;
         unsafe {
@@ -258,7 +252,7 @@ impl IIOControlCode {
             (::windows::core::Interface::vtable(this).AccessMode)(::core::mem::transmute_copy(this), &mut result__).from_abi::<IOControlAccessMode>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn BufferingMethod(&self) -> ::windows::core::Result<IOControlBufferingMethod> {
         let this = self;
         unsafe {
@@ -266,7 +260,7 @@ impl IIOControlCode {
             (::windows::core::Interface::vtable(this).BufferingMethod)(::core::mem::transmute_copy(this), &mut result__).from_abi::<IOControlBufferingMethod>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn Function(&self) -> ::windows::core::Result<u16> {
         let this = self;
         unsafe {
@@ -274,7 +268,7 @@ impl IIOControlCode {
             (::windows::core::Interface::vtable(this).Function)(::core::mem::transmute_copy(this), &mut result__).from_abi::<u16>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn DeviceType(&self) -> ::windows::core::Result<u16> {
         let this = self;
         unsafe {
@@ -282,7 +276,7 @@ impl IIOControlCode {
             (::windows::core::Interface::vtable(this).DeviceType)(::core::mem::transmute_copy(this), &mut result__).from_abi::<u16>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn ControlCode(&self) -> ::windows::core::Result<u32> {
         let this = self;
         unsafe {
@@ -306,7 +300,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IIOContro
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IIOControlCode {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IIOControlCode {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -326,7 +320,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for IIOCo
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a IIOControlCode {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &IIOControlCode {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -349,10 +343,6 @@ impl ::core::fmt::Debug for IIOControlCode {
 }
 unsafe impl ::windows::core::RuntimeType for IIOControlCode {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"{0e9559e7-60c8-4375-a761-7f8808066c60}");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for IIOControlCode {
     type Vtable = IIOControlCode_Vtbl;
@@ -394,7 +384,7 @@ pub struct IKnownDeviceTypesStatics_Vtbl {
     pub base: ::windows::core::IInspectableVtbl,
     pub Unknown: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut u16) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: `\"Devices_Custom\"`*"]
+#[doc = "*Required features: 'Devices_Custom'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct IOControlAccessMode(pub i32);
@@ -425,12 +415,11 @@ impl ::core::fmt::Debug for IOControlAccessMode {
 }
 unsafe impl ::windows::core::RuntimeType for IOControlAccessMode {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.Custom.IOControlAccessMode;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Devices_Custom\"`*"]
+impl ::windows::core::DefaultType for IOControlAccessMode {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Devices_Custom'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct IOControlBufferingMethod(pub i32);
@@ -461,16 +450,15 @@ impl ::core::fmt::Debug for IOControlBufferingMethod {
 }
 unsafe impl ::windows::core::RuntimeType for IOControlBufferingMethod {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Devices.Custom.IOControlBufferingMethod;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"Devices_Custom\"`*"]
+impl ::windows::core::DefaultType for IOControlBufferingMethod {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'Devices_Custom'*"]
 #[repr(transparent)]
 pub struct IOControlCode(::windows::core::IUnknown);
 impl IOControlCode {
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn AccessMode(&self) -> ::windows::core::Result<IOControlAccessMode> {
         let this = self;
         unsafe {
@@ -478,7 +466,7 @@ impl IOControlCode {
             (::windows::core::Interface::vtable(this).AccessMode)(::core::mem::transmute_copy(this), &mut result__).from_abi::<IOControlAccessMode>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn BufferingMethod(&self) -> ::windows::core::Result<IOControlBufferingMethod> {
         let this = self;
         unsafe {
@@ -486,7 +474,7 @@ impl IOControlCode {
             (::windows::core::Interface::vtable(this).BufferingMethod)(::core::mem::transmute_copy(this), &mut result__).from_abi::<IOControlBufferingMethod>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn Function(&self) -> ::windows::core::Result<u16> {
         let this = self;
         unsafe {
@@ -494,7 +482,7 @@ impl IOControlCode {
             (::windows::core::Interface::vtable(this).Function)(::core::mem::transmute_copy(this), &mut result__).from_abi::<u16>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn DeviceType(&self) -> ::windows::core::Result<u16> {
         let this = self;
         unsafe {
@@ -502,7 +490,7 @@ impl IOControlCode {
             (::windows::core::Interface::vtable(this).DeviceType)(::core::mem::transmute_copy(this), &mut result__).from_abi::<u16>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn ControlCode(&self) -> ::windows::core::Result<u32> {
         let this = self;
         unsafe {
@@ -510,7 +498,7 @@ impl IOControlCode {
             (::windows::core::Interface::vtable(this).ControlCode)(::core::mem::transmute_copy(this), &mut result__).from_abi::<u32>(result__)
         }
     }
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn CreateIOControlCode(devicetype: u16, function: u16, accessmode: IOControlAccessMode, bufferingmethod: IOControlBufferingMethod) -> ::windows::core::Result<IOControlCode> {
         Self::IIOControlCodeFactory(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
@@ -541,10 +529,6 @@ impl ::core::fmt::Debug for IOControlCode {
 }
 unsafe impl ::windows::core::RuntimeType for IOControlCode {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Devices.Custom.IOControlCode;{0e9559e7-60c8-4375-a761-7f8808066c60})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for IOControlCode {
     type Vtable = IIOControlCode_Vtbl;
@@ -568,7 +552,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IOControl
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IOControlCode {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IOControlCode {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -588,7 +572,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for IOCon
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a IOControlCode {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &IOControlCode {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -617,10 +601,10 @@ impl<'a> ::windows::core::IntoParam<'a, IIOControlCode> for &IOControlCode {
 }
 unsafe impl ::core::marker::Send for IOControlCode {}
 unsafe impl ::core::marker::Sync for IOControlCode {}
-#[doc = "*Required features: `\"Devices_Custom\"`*"]
+#[doc = "*Required features: 'Devices_Custom'*"]
 pub struct KnownDeviceTypes {}
 impl KnownDeviceTypes {
-    #[doc = "*Required features: `\"Devices_Custom\"`*"]
+    #[doc = "*Required features: 'Devices_Custom'*"]
     pub fn Unknown() -> ::windows::core::Result<u16> {
         Self::IKnownDeviceTypesStatics(|this| unsafe {
             let mut result__: u16 = ::core::mem::zeroed();
