@@ -1,9 +1,9 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+#[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
 #[repr(transparent)]
 pub struct AnimationDescription(::windows::core::IUnknown);
 impl AnimationDescription {
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation_Collections\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation_Collections'*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn Animations(&self) -> ::windows::core::Result<super::super::super::Foundation::Collections::IVectorView<IPropertyAnimation>> {
         let this = self;
@@ -12,7 +12,7 @@ impl AnimationDescription {
             (::windows::core::Interface::vtable(this).Animations)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Collections::IVectorView<IPropertyAnimation>>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn StaggerDelay(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = self;
@@ -21,7 +21,7 @@ impl AnimationDescription {
             (::windows::core::Interface::vtable(this).StaggerDelay)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn StaggerDelayFactor(&self) -> ::windows::core::Result<f32> {
         let this = self;
         unsafe {
@@ -29,7 +29,7 @@ impl AnimationDescription {
             (::windows::core::Interface::vtable(this).StaggerDelayFactor)(::core::mem::transmute_copy(this), &mut result__).from_abi::<f32>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn DelayLimit(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = self;
@@ -38,7 +38,7 @@ impl AnimationDescription {
             (::windows::core::Interface::vtable(this).DelayLimit)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn ZOrder(&self) -> ::windows::core::Result<i32> {
         let this = self;
         unsafe {
@@ -46,7 +46,7 @@ impl AnimationDescription {
             (::windows::core::Interface::vtable(this).ZOrder)(::core::mem::transmute_copy(this), &mut result__).from_abi::<i32>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn CreateInstance(effect: AnimationEffect, target: AnimationEffectTarget) -> ::windows::core::Result<AnimationDescription> {
         Self::IAnimationDescriptionFactory(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
@@ -77,10 +77,6 @@ impl ::core::fmt::Debug for AnimationDescription {
 }
 unsafe impl ::windows::core::RuntimeType for AnimationDescription {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.UI.Core.AnimationMetrics.AnimationDescription;{7d11a549-be3d-41de-b081-05c149962f9b})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for AnimationDescription {
     type Vtable = IAnimationDescription_Vtbl;
@@ -104,7 +100,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for Animation
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a AnimationDescription {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &AnimationDescription {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -124,14 +120,14 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for Anima
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a AnimationDescription {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &AnimationDescription {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for AnimationDescription {}
 unsafe impl ::core::marker::Sync for AnimationDescription {}
-#[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+#[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct AnimationEffect(pub i32);
@@ -194,12 +190,11 @@ impl ::core::fmt::Debug for AnimationEffect {
 }
 unsafe impl ::windows::core::RuntimeType for AnimationEffect {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.UI.Core.AnimationMetrics.AnimationEffect;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+impl ::windows::core::DefaultType for AnimationEffect {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct AnimationEffectTarget(pub i32);
@@ -246,10 +241,9 @@ impl ::core::fmt::Debug for AnimationEffectTarget {
 }
 unsafe impl ::windows::core::RuntimeType for AnimationEffectTarget {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.UI.Core.AnimationMetrics.AnimationEffectTarget;i4)");
+}
+impl ::windows::core::DefaultType for AnimationEffectTarget {
     type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
 #[doc(hidden)]
 #[repr(transparent)]
@@ -307,11 +301,11 @@ pub struct IOpacityAnimation_Vtbl {
     InitialOpacity: usize,
     pub FinalOpacity: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut f32) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+#[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
 #[repr(transparent)]
 pub struct IPropertyAnimation(::windows::core::IUnknown);
 impl IPropertyAnimation {
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn Type(&self) -> ::windows::core::Result<PropertyAnimationType> {
         let this = self;
         unsafe {
@@ -319,7 +313,7 @@ impl IPropertyAnimation {
             (::windows::core::Interface::vtable(this).Type)(::core::mem::transmute_copy(this), &mut result__).from_abi::<PropertyAnimationType>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Delay(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = self;
@@ -328,7 +322,7 @@ impl IPropertyAnimation {
             (::windows::core::Interface::vtable(this).Delay)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Duration(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = self;
@@ -337,7 +331,7 @@ impl IPropertyAnimation {
             (::windows::core::Interface::vtable(this).Duration)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Control1(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = self;
@@ -346,7 +340,7 @@ impl IPropertyAnimation {
             (::windows::core::Interface::vtable(this).Control1)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Point>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Control2(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = self;
@@ -371,7 +365,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IProperty
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IPropertyAnimation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IPropertyAnimation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -391,7 +385,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for IProp
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a IPropertyAnimation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &IPropertyAnimation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -414,10 +408,6 @@ impl ::core::fmt::Debug for IPropertyAnimation {
 }
 unsafe impl ::windows::core::RuntimeType for IPropertyAnimation {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"{3a01b4da-4d8c-411e-b615-1ade683a9903}");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for IPropertyAnimation {
     type Vtable = IPropertyAnimation_Vtbl;
@@ -471,11 +461,11 @@ pub struct IScaleAnimation_Vtbl {
     #[cfg(not(feature = "Foundation"))]
     NormalizedOrigin: usize,
 }
-#[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+#[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
 #[repr(transparent)]
 pub struct OpacityAnimation(::windows::core::IUnknown);
 impl OpacityAnimation {
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn InitialOpacity(&self) -> ::windows::core::Result<super::super::super::Foundation::IReference<f32>> {
         let this = self;
@@ -484,7 +474,7 @@ impl OpacityAnimation {
             (::windows::core::Interface::vtable(this).InitialOpacity)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::IReference<f32>>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn FinalOpacity(&self) -> ::windows::core::Result<f32> {
         let this = self;
         unsafe {
@@ -492,7 +482,7 @@ impl OpacityAnimation {
             (::windows::core::Interface::vtable(this).FinalOpacity)(::core::mem::transmute_copy(this), &mut result__).from_abi::<f32>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn Type(&self) -> ::windows::core::Result<PropertyAnimationType> {
         let this = &::windows::core::Interface::cast::<IPropertyAnimation>(self)?;
         unsafe {
@@ -500,7 +490,7 @@ impl OpacityAnimation {
             (::windows::core::Interface::vtable(this).Type)(::core::mem::transmute_copy(this), &mut result__).from_abi::<PropertyAnimationType>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Delay(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = &::windows::core::Interface::cast::<IPropertyAnimation>(self)?;
@@ -509,7 +499,7 @@ impl OpacityAnimation {
             (::windows::core::Interface::vtable(this).Delay)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Duration(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = &::windows::core::Interface::cast::<IPropertyAnimation>(self)?;
@@ -518,7 +508,7 @@ impl OpacityAnimation {
             (::windows::core::Interface::vtable(this).Duration)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Control1(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = &::windows::core::Interface::cast::<IPropertyAnimation>(self)?;
@@ -527,7 +517,7 @@ impl OpacityAnimation {
             (::windows::core::Interface::vtable(this).Control1)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Point>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Control2(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = &::windows::core::Interface::cast::<IPropertyAnimation>(self)?;
@@ -555,10 +545,6 @@ impl ::core::fmt::Debug for OpacityAnimation {
 }
 unsafe impl ::windows::core::RuntimeType for OpacityAnimation {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.UI.Core.AnimationMetrics.OpacityAnimation;{803aabe5-ee7e-455f-84e9-2506afb8d2b4})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for OpacityAnimation {
     type Vtable = IOpacityAnimation_Vtbl;
@@ -582,7 +568,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for OpacityAn
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a OpacityAnimation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &OpacityAnimation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -602,7 +588,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for Opaci
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a OpacityAnimation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &OpacityAnimation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -631,11 +617,11 @@ impl<'a> ::windows::core::IntoParam<'a, IPropertyAnimation> for &OpacityAnimatio
 }
 unsafe impl ::core::marker::Send for OpacityAnimation {}
 unsafe impl ::core::marker::Sync for OpacityAnimation {}
-#[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+#[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
 #[repr(transparent)]
 pub struct PropertyAnimation(::windows::core::IUnknown);
 impl PropertyAnimation {
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn Type(&self) -> ::windows::core::Result<PropertyAnimationType> {
         let this = self;
         unsafe {
@@ -643,7 +629,7 @@ impl PropertyAnimation {
             (::windows::core::Interface::vtable(this).Type)(::core::mem::transmute_copy(this), &mut result__).from_abi::<PropertyAnimationType>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Delay(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = self;
@@ -652,7 +638,7 @@ impl PropertyAnimation {
             (::windows::core::Interface::vtable(this).Delay)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Duration(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = self;
@@ -661,7 +647,7 @@ impl PropertyAnimation {
             (::windows::core::Interface::vtable(this).Duration)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Control1(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = self;
@@ -670,7 +656,7 @@ impl PropertyAnimation {
             (::windows::core::Interface::vtable(this).Control1)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Point>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Control2(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = self;
@@ -698,10 +684,6 @@ impl ::core::fmt::Debug for PropertyAnimation {
 }
 unsafe impl ::windows::core::RuntimeType for PropertyAnimation {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.UI.Core.AnimationMetrics.PropertyAnimation;{3a01b4da-4d8c-411e-b615-1ade683a9903})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for PropertyAnimation {
     type Vtable = IPropertyAnimation_Vtbl;
@@ -725,7 +707,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for PropertyA
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a PropertyAnimation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &PropertyAnimation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -745,7 +727,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for Prope
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a PropertyAnimation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &PropertyAnimation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -774,7 +756,7 @@ impl<'a> ::windows::core::IntoParam<'a, IPropertyAnimation> for &PropertyAnimati
 }
 unsafe impl ::core::marker::Send for PropertyAnimation {}
 unsafe impl ::core::marker::Sync for PropertyAnimation {}
-#[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+#[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct PropertyAnimationType(pub i32);
@@ -804,16 +786,15 @@ impl ::core::fmt::Debug for PropertyAnimationType {
 }
 unsafe impl ::windows::core::RuntimeType for PropertyAnimationType {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.UI.Core.AnimationMetrics.PropertyAnimationType;i4)");
-    type DefaultType = Self;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        Ok(*from)
-    }
 }
-#[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+impl ::windows::core::DefaultType for PropertyAnimationType {
+    type DefaultType = Self;
+}
+#[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
 #[repr(transparent)]
 pub struct ScaleAnimation(::windows::core::IUnknown);
 impl ScaleAnimation {
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn Type(&self) -> ::windows::core::Result<PropertyAnimationType> {
         let this = &::windows::core::Interface::cast::<IPropertyAnimation>(self)?;
         unsafe {
@@ -821,7 +802,7 @@ impl ScaleAnimation {
             (::windows::core::Interface::vtable(this).Type)(::core::mem::transmute_copy(this), &mut result__).from_abi::<PropertyAnimationType>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Delay(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = &::windows::core::Interface::cast::<IPropertyAnimation>(self)?;
@@ -830,7 +811,7 @@ impl ScaleAnimation {
             (::windows::core::Interface::vtable(this).Delay)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Duration(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = &::windows::core::Interface::cast::<IPropertyAnimation>(self)?;
@@ -839,7 +820,7 @@ impl ScaleAnimation {
             (::windows::core::Interface::vtable(this).Duration)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Control1(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = &::windows::core::Interface::cast::<IPropertyAnimation>(self)?;
@@ -848,7 +829,7 @@ impl ScaleAnimation {
             (::windows::core::Interface::vtable(this).Control1)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Point>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Control2(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = &::windows::core::Interface::cast::<IPropertyAnimation>(self)?;
@@ -857,7 +838,7 @@ impl ScaleAnimation {
             (::windows::core::Interface::vtable(this).Control2)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Point>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn InitialScaleX(&self) -> ::windows::core::Result<super::super::super::Foundation::IReference<f32>> {
         let this = self;
@@ -866,7 +847,7 @@ impl ScaleAnimation {
             (::windows::core::Interface::vtable(this).InitialScaleX)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::IReference<f32>>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn InitialScaleY(&self) -> ::windows::core::Result<super::super::super::Foundation::IReference<f32>> {
         let this = self;
@@ -875,7 +856,7 @@ impl ScaleAnimation {
             (::windows::core::Interface::vtable(this).InitialScaleY)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::IReference<f32>>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn FinalScaleX(&self) -> ::windows::core::Result<f32> {
         let this = self;
         unsafe {
@@ -883,7 +864,7 @@ impl ScaleAnimation {
             (::windows::core::Interface::vtable(this).FinalScaleX)(::core::mem::transmute_copy(this), &mut result__).from_abi::<f32>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn FinalScaleY(&self) -> ::windows::core::Result<f32> {
         let this = self;
         unsafe {
@@ -891,7 +872,7 @@ impl ScaleAnimation {
             (::windows::core::Interface::vtable(this).FinalScaleY)(::core::mem::transmute_copy(this), &mut result__).from_abi::<f32>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn NormalizedOrigin(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = self;
@@ -919,10 +900,6 @@ impl ::core::fmt::Debug for ScaleAnimation {
 }
 unsafe impl ::windows::core::RuntimeType for ScaleAnimation {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.UI.Core.AnimationMetrics.ScaleAnimation;{023552c7-71ab-428c-9c9f-d31780964995})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for ScaleAnimation {
     type Vtable = IScaleAnimation_Vtbl;
@@ -946,7 +923,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for ScaleAnim
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a ScaleAnimation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &ScaleAnimation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -966,7 +943,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for Scale
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a ScaleAnimation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &ScaleAnimation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -995,11 +972,11 @@ impl<'a> ::windows::core::IntoParam<'a, IPropertyAnimation> for &ScaleAnimation
 }
 unsafe impl ::core::marker::Send for ScaleAnimation {}
 unsafe impl ::core::marker::Sync for ScaleAnimation {}
-#[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+#[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
 #[repr(transparent)]
 pub struct TranslationAnimation(::windows::core::IUnknown);
 impl TranslationAnimation {
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics'*"]
     pub fn Type(&self) -> ::windows::core::Result<PropertyAnimationType> {
         let this = self;
         unsafe {
@@ -1007,7 +984,7 @@ impl TranslationAnimation {
             (::windows::core::Interface::vtable(this).Type)(::core::mem::transmute_copy(this), &mut result__).from_abi::<PropertyAnimationType>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Delay(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = self;
@@ -1016,7 +993,7 @@ impl TranslationAnimation {
             (::windows::core::Interface::vtable(this).Delay)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Duration(&self) -> ::windows::core::Result<super::super::super::Foundation::TimeSpan> {
         let this = self;
@@ -1025,7 +1002,7 @@ impl TranslationAnimation {
             (::windows::core::Interface::vtable(this).Duration)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::TimeSpan>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Control1(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = self;
@@ -1034,7 +1011,7 @@ impl TranslationAnimation {
             (::windows::core::Interface::vtable(this).Control1)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Point>(result__)
         }
     }
-    #[doc = "*Required features: `\"UI_Core_AnimationMetrics\"`, `\"Foundation\"`*"]
+    #[doc = "*Required features: 'UI_Core_AnimationMetrics', 'Foundation'*"]
     #[cfg(feature = "Foundation")]
     pub fn Control2(&self) -> ::windows::core::Result<super::super::super::Foundation::Point> {
         let this = self;
@@ -1062,10 +1039,6 @@ impl ::core::fmt::Debug for TranslationAnimation {
 }
 unsafe impl ::windows::core::RuntimeType for TranslationAnimation {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.UI.Core.AnimationMetrics.TranslationAnimation;{3a01b4da-4d8c-411e-b615-1ade683a9903})");
-    type DefaultType = ::core::option::Option<Self>;
-    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
-        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
-    }
 }
 unsafe impl ::windows::core::Interface for TranslationAnimation {
     type Vtable = IPropertyAnimation_Vtbl;
@@ -1089,7 +1062,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for Translati
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a TranslationAnimation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &TranslationAnimation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -1109,7 +1082,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for Trans
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a TranslationAnimation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &TranslationAnimation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
