@@ -68,7 +68,7 @@ unsafe impl ::windows::core::Abi for HPSSWALK {
     type Abi = Self;
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_ALLOCATOR {
     pub Context: *mut ::core::ffi::c_void,
     pub AllocRoutine: isize,
@@ -100,7 +100,7 @@ impl ::core::default::Default for PSS_ALLOCATOR {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_AUXILIARY_PAGES_INFORMATION {
     pub AuxPagesCaptured: u32,
 }
@@ -130,7 +130,7 @@ impl ::core::default::Default for PSS_AUXILIARY_PAGES_INFORMATION {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`, `\"Win32_System_Memory\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation', 'Win32_System_Memory'*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Memory"))]
 pub struct PSS_AUXILIARY_PAGE_ENTRY {
     pub Address: *mut ::core::ffi::c_void,
@@ -171,53 +171,53 @@ impl ::core::default::Default for PSS_AUXILIARY_PAGE_ENTRY {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct PSS_CAPTURE_FLAGS(pub u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_NONE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(0u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_VA_CLONE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(1u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_RESERVED_00000002: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(2u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_HANDLES: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(4u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_HANDLE_NAME_INFORMATION: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(8u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_HANDLE_BASIC_INFORMATION: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(16u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_HANDLE_TYPE_SPECIFIC_INFORMATION: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(32u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_HANDLE_TRACE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(64u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_THREADS: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(128u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_THREAD_CONTEXT: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(256u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_THREAD_CONTEXT_EXTENDED: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(512u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_RESERVED_00000400: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(1024u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_VA_SPACE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(2048u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_VA_SPACE_SECTION_INFORMATION: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(4096u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_IPT_TRACE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(8192u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CAPTURE_RESERVED_00004000: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(16384u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CREATE_BREAKAWAY_OPTIONAL: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(67108864u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CREATE_BREAKAWAY: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(134217728u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CREATE_FORCE_BREAKAWAY: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(268435456u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CREATE_USE_VM_ALLOCATIONS: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(536870912u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CREATE_MEASURE_PERFORMANCE: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(1073741824u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_CREATE_RELEASE_SECTION: PSS_CAPTURE_FLAGS = PSS_CAPTURE_FLAGS(2147483648u32);
 impl ::core::marker::Copy for PSS_CAPTURE_FLAGS {}
 impl ::core::clone::Clone for PSS_CAPTURE_FLAGS {
@@ -266,13 +266,13 @@ impl ::core::ops::Not for PSS_CAPTURE_FLAGS {
         Self(self.0.not())
     }
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct PSS_DUPLICATE_FLAGS(pub u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_DUPLICATE_NONE: PSS_DUPLICATE_FLAGS = PSS_DUPLICATE_FLAGS(0u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_DUPLICATE_CLOSE_SOURCE: PSS_DUPLICATE_FLAGS = PSS_DUPLICATE_FLAGS(1u32);
 impl ::core::marker::Copy for PSS_DUPLICATE_FLAGS {}
 impl ::core::clone::Clone for PSS_DUPLICATE_FLAGS {
@@ -322,7 +322,7 @@ impl ::core::ops::Not for PSS_DUPLICATE_FLAGS {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY {
     pub Handle: super::super::super::Foundation::HANDLE,
@@ -337,9 +337,9 @@ pub struct PSS_HANDLE_ENTRY {
     pub NonPagedPoolCharge: u32,
     pub CreationTime: super::super::super::Foundation::FILETIME,
     pub TypeNameLength: u16,
-    pub TypeName: ::windows::core::PCWSTR,
+    pub TypeName: super::super::super::Foundation::PWSTR,
     pub ObjectNameLength: u16,
-    pub ObjectName: ::windows::core::PCWSTR,
+    pub ObjectName: super::super::super::Foundation::PWSTR,
     pub TypeSpecificInformation: PSS_HANDLE_ENTRY_0,
 }
 #[cfg(feature = "Win32_Foundation")]
@@ -369,7 +369,7 @@ impl ::core::default::Default for PSS_HANDLE_ENTRY {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub union PSS_HANDLE_ENTRY_0 {
     pub Process: PSS_HANDLE_ENTRY_0_2,
@@ -406,7 +406,7 @@ impl ::core::default::Default for PSS_HANDLE_ENTRY_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_0 {
     pub ManualReset: super::super::super::Foundation::BOOL,
@@ -445,7 +445,7 @@ impl ::core::default::Default for PSS_HANDLE_ENTRY_0_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_1 {
     pub CurrentCount: i32,
@@ -486,7 +486,7 @@ impl ::core::default::Default for PSS_HANDLE_ENTRY_0_1 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_2 {
     pub ExitStatus: u32,
@@ -530,7 +530,7 @@ impl ::core::default::Default for PSS_HANDLE_ENTRY_0_2 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_3 {
     pub BaseAddress: *mut ::core::ffi::c_void,
@@ -570,7 +570,7 @@ impl ::core::default::Default for PSS_HANDLE_ENTRY_0_3 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_4 {
     pub CurrentCount: i32,
@@ -609,7 +609,7 @@ impl ::core::default::Default for PSS_HANDLE_ENTRY_0_4 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_ENTRY_0_5 {
     pub ExitStatus: u32,
@@ -653,19 +653,19 @@ impl ::core::default::Default for PSS_HANDLE_ENTRY_0_5 {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct PSS_HANDLE_FLAGS(pub u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_HANDLE_NONE: PSS_HANDLE_FLAGS = PSS_HANDLE_FLAGS(0u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_HANDLE_HAVE_TYPE: PSS_HANDLE_FLAGS = PSS_HANDLE_FLAGS(1u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_HANDLE_HAVE_NAME: PSS_HANDLE_FLAGS = PSS_HANDLE_FLAGS(2u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_HANDLE_HAVE_BASIC_INFORMATION: PSS_HANDLE_FLAGS = PSS_HANDLE_FLAGS(4u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_HANDLE_HAVE_TYPE_SPECIFIC_INFORMATION: PSS_HANDLE_FLAGS = PSS_HANDLE_FLAGS(8u32);
 impl ::core::marker::Copy for PSS_HANDLE_FLAGS {}
 impl ::core::clone::Clone for PSS_HANDLE_FLAGS {
@@ -715,7 +715,7 @@ impl ::core::ops::Not for PSS_HANDLE_FLAGS {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_HANDLE_INFORMATION {
     pub HandlesCaptured: u32,
 }
@@ -745,7 +745,7 @@ impl ::core::default::Default for PSS_HANDLE_INFORMATION {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_HANDLE_TRACE_INFORMATION {
     pub SectionHandle: super::super::super::Foundation::HANDLE,
@@ -783,23 +783,23 @@ impl ::core::default::Default for PSS_HANDLE_TRACE_INFORMATION {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct PSS_OBJECT_TYPE(pub i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_OBJECT_TYPE_UNKNOWN: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(0i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_OBJECT_TYPE_PROCESS: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(1i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_OBJECT_TYPE_THREAD: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(2i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_OBJECT_TYPE_MUTANT: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(3i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_OBJECT_TYPE_EVENT: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(4i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_OBJECT_TYPE_SECTION: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(5i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_OBJECT_TYPE_SEMAPHORE: PSS_OBJECT_TYPE = PSS_OBJECT_TYPE(6i32);
 impl ::core::marker::Copy for PSS_OBJECT_TYPE {}
 impl ::core::clone::Clone for PSS_OBJECT_TYPE {
@@ -821,7 +821,7 @@ impl ::core::fmt::Debug for PSS_OBJECT_TYPE {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_PERFORMANCE_COUNTERS {
     pub TotalCycleCount: u64,
     pub TotalWallClockPeriod: u64,
@@ -874,23 +874,23 @@ impl ::core::default::Default for PSS_PERFORMANCE_COUNTERS {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_PERF_RESOLUTION: u32 = 1000000u32;
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct PSS_PROCESS_FLAGS(pub u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_PROCESS_FLAGS_NONE: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(0u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_PROCESS_FLAGS_PROTECTED: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(1u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_PROCESS_FLAGS_WOW64: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(2u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_PROCESS_FLAGS_RESERVED_03: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(4u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_PROCESS_FLAGS_RESERVED_04: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(8u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_PROCESS_FLAGS_FROZEN: PSS_PROCESS_FLAGS = PSS_PROCESS_FLAGS(16u32);
 impl ::core::marker::Copy for PSS_PROCESS_FLAGS {}
 impl ::core::clone::Clone for PSS_PROCESS_FLAGS {
@@ -940,7 +940,7 @@ impl ::core::ops::Not for PSS_PROCESS_FLAGS {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_PROCESS_INFORMATION {
     pub ExitStatus: u32,
@@ -1029,25 +1029,25 @@ impl ::core::default::Default for PSS_PROCESS_INFORMATION {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct PSS_QUERY_INFORMATION_CLASS(pub i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_QUERY_PROCESS_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(0i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_QUERY_VA_CLONE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(1i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_QUERY_AUXILIARY_PAGES_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(2i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_QUERY_VA_SPACE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(3i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_QUERY_HANDLE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(4i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_QUERY_THREAD_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(5i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_QUERY_HANDLE_TRACE_INFORMATION: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(6i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_QUERY_PERFORMANCE_COUNTERS: PSS_QUERY_INFORMATION_CLASS = PSS_QUERY_INFORMATION_CLASS(7i32);
 impl ::core::marker::Copy for PSS_QUERY_INFORMATION_CLASS {}
 impl ::core::clone::Clone for PSS_QUERY_INFORMATION_CLASS {
@@ -1069,7 +1069,7 @@ impl ::core::fmt::Debug for PSS_QUERY_INFORMATION_CLASS {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`, `\"Win32_System_Kernel\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Kernel'*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Kernel"))]
 pub struct PSS_THREAD_ENTRY {
     pub ExitStatus: u32,
@@ -1144,13 +1144,13 @@ impl ::core::default::Default for PSS_THREAD_ENTRY {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct PSS_THREAD_FLAGS(pub u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_THREAD_FLAGS_NONE: PSS_THREAD_FLAGS = PSS_THREAD_FLAGS(0u32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_THREAD_FLAGS_TERMINATED: PSS_THREAD_FLAGS = PSS_THREAD_FLAGS(1u32);
 impl ::core::marker::Copy for PSS_THREAD_FLAGS {}
 impl ::core::clone::Clone for PSS_THREAD_FLAGS {
@@ -1200,7 +1200,7 @@ impl ::core::ops::Not for PSS_THREAD_FLAGS {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_THREAD_INFORMATION {
     pub ThreadsCaptured: u32,
     pub ContextLength: u32,
@@ -1231,7 +1231,7 @@ impl ::core::default::Default for PSS_THREAD_INFORMATION {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct PSS_VA_CLONE_INFORMATION {
     pub VaCloneHandle: super::super::super::Foundation::HANDLE,
@@ -1269,7 +1269,8 @@ impl ::core::default::Default for PSS_VA_CLONE_INFORMATION {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
+#[cfg(feature = "Win32_Foundation")]
 pub struct PSS_VA_SPACE_ENTRY {
     pub BaseAddress: *mut ::core::ffi::c_void,
     pub AllocationBase: *mut ::core::ffi::c_void,
@@ -1283,14 +1284,17 @@ pub struct PSS_VA_SPACE_ENTRY {
     pub ImageBase: *mut ::core::ffi::c_void,
     pub CheckSum: u32,
     pub MappedFileNameLength: u16,
-    pub MappedFileName: ::windows::core::PCWSTR,
+    pub MappedFileName: super::super::super::Foundation::PWSTR,
 }
+#[cfg(feature = "Win32_Foundation")]
 impl ::core::marker::Copy for PSS_VA_SPACE_ENTRY {}
+#[cfg(feature = "Win32_Foundation")]
 impl ::core::clone::Clone for PSS_VA_SPACE_ENTRY {
     fn clone(&self) -> Self {
         *self
     }
 }
+#[cfg(feature = "Win32_Foundation")]
 impl ::core::fmt::Debug for PSS_VA_SPACE_ENTRY {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         f.debug_struct("PSS_VA_SPACE_ENTRY")
@@ -1310,22 +1314,26 @@ impl ::core::fmt::Debug for PSS_VA_SPACE_ENTRY {
             .finish()
     }
 }
+#[cfg(feature = "Win32_Foundation")]
 unsafe impl ::windows::core::Abi for PSS_VA_SPACE_ENTRY {
     type Abi = Self;
 }
+#[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::PartialEq for PSS_VA_SPACE_ENTRY {
     fn eq(&self, other: &Self) -> bool {
         unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<PSS_VA_SPACE_ENTRY>()) == 0 }
     }
 }
+#[cfg(feature = "Win32_Foundation")]
 impl ::core::cmp::Eq for PSS_VA_SPACE_ENTRY {}
+#[cfg(feature = "Win32_Foundation")]
 impl ::core::default::Default for PSS_VA_SPACE_ENTRY {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
     }
 }
 #[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub struct PSS_VA_SPACE_INFORMATION {
     pub RegionCount: u32,
 }
@@ -1354,17 +1362,17 @@ impl ::core::default::Default for PSS_VA_SPACE_INFORMATION {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct PSS_WALK_INFORMATION_CLASS(pub i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_WALK_AUXILIARY_PAGES: PSS_WALK_INFORMATION_CLASS = PSS_WALK_INFORMATION_CLASS(0i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_WALK_VA_SPACE: PSS_WALK_INFORMATION_CLASS = PSS_WALK_INFORMATION_CLASS(1i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_WALK_HANDLES: PSS_WALK_INFORMATION_CLASS = PSS_WALK_INFORMATION_CLASS(2i32);
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 pub const PSS_WALK_THREADS: PSS_WALK_INFORMATION_CLASS = PSS_WALK_INFORMATION_CLASS(3i32);
 impl ::core::marker::Copy for PSS_WALK_INFORMATION_CLASS {}
 impl ::core::clone::Clone for PSS_WALK_INFORMATION_CLASS {
@@ -1385,7 +1393,7 @@ impl ::core::fmt::Debug for PSS_WALK_INFORMATION_CLASS {
         f.debug_tuple("PSS_WALK_INFORMATION_CLASS").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn PssCaptureSnapshot<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::HANDLE>>(processhandle: Param0, captureflags: PSS_CAPTURE_FLAGS, threadcontextflags: u32, snapshothandle: *mut HPSS) -> u32 {
@@ -1400,7 +1408,7 @@ pub unsafe fn PssCaptureSnapshot<'a, Param0: ::windows::core::IntoParam<'a, supe
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn PssDuplicateSnapshot<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::HANDLE>, Param1: ::windows::core::IntoParam<'a, HPSS>, Param2: ::windows::core::IntoParam<'a, super::super::super::Foundation::HANDLE>>(sourceprocesshandle: Param0, snapshothandle: Param1, targetprocesshandle: Param2, targetsnapshothandle: *mut HPSS, flags: PSS_DUPLICATE_FLAGS) -> u32 {
@@ -1415,7 +1423,7 @@ pub unsafe fn PssDuplicateSnapshot<'a, Param0: ::windows::core::IntoParam<'a, su
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`, `\"Win32_Foundation\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn PssFreeSnapshot<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::HANDLE>, Param1: ::windows::core::IntoParam<'a, HPSS>>(processhandle: Param0, snapshothandle: Param1) -> u32 {
@@ -1430,7 +1438,7 @@ pub unsafe fn PssFreeSnapshot<'a, Param0: ::windows::core::IntoParam<'a, super::
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[inline]
 pub unsafe fn PssQuerySnapshot<'a, Param0: ::windows::core::IntoParam<'a, HPSS>>(snapshothandle: Param0, informationclass: PSS_QUERY_INFORMATION_CLASS, buffer: *mut ::core::ffi::c_void, bufferlength: u32) -> u32 {
     #[cfg(windows)]
@@ -1444,7 +1452,7 @@ pub unsafe fn PssQuerySnapshot<'a, Param0: ::windows::core::IntoParam<'a, HPSS>>
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[inline]
 pub unsafe fn PssWalkMarkerCreate(allocator: *const PSS_ALLOCATOR, walkmarkerhandle: *mut HPSSWALK) -> u32 {
     #[cfg(windows)]
@@ -1458,7 +1466,7 @@ pub unsafe fn PssWalkMarkerCreate(allocator: *const PSS_ALLOCATOR, walkmarkerhan
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[inline]
 pub unsafe fn PssWalkMarkerFree<'a, Param0: ::windows::core::IntoParam<'a, HPSSWALK>>(walkmarkerhandle: Param0) -> u32 {
     #[cfg(windows)]
@@ -1472,7 +1480,7 @@ pub unsafe fn PssWalkMarkerFree<'a, Param0: ::windows::core::IntoParam<'a, HPSSW
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[inline]
 pub unsafe fn PssWalkMarkerGetPosition<'a, Param0: ::windows::core::IntoParam<'a, HPSSWALK>>(walkmarkerhandle: Param0, position: *mut usize) -> u32 {
     #[cfg(windows)]
@@ -1486,7 +1494,7 @@ pub unsafe fn PssWalkMarkerGetPosition<'a, Param0: ::windows::core::IntoParam<'a
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[inline]
 pub unsafe fn PssWalkMarkerSeekToBeginning<'a, Param0: ::windows::core::IntoParam<'a, HPSSWALK>>(walkmarkerhandle: Param0) -> u32 {
     #[cfg(windows)]
@@ -1500,7 +1508,7 @@ pub unsafe fn PssWalkMarkerSeekToBeginning<'a, Param0: ::windows::core::IntoPara
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[inline]
 pub unsafe fn PssWalkMarkerSetPosition<'a, Param0: ::windows::core::IntoParam<'a, HPSSWALK>>(walkmarkerhandle: Param0, position: usize) -> u32 {
     #[cfg(windows)]
@@ -1514,16 +1522,16 @@ pub unsafe fn PssWalkMarkerSetPosition<'a, Param0: ::windows::core::IntoParam<'a
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `\"Win32_System_Diagnostics_ProcessSnapshotting\"`*"]
+#[doc = "*Required features: 'Win32_System_Diagnostics_ProcessSnapshotting'*"]
 #[inline]
-pub unsafe fn PssWalkSnapshot<'a, Param0: ::windows::core::IntoParam<'a, HPSS>, Param2: ::windows::core::IntoParam<'a, HPSSWALK>>(snapshothandle: Param0, informationclass: PSS_WALK_INFORMATION_CLASS, walkmarkerhandle: Param2, buffer: &mut [u8]) -> u32 {
+pub unsafe fn PssWalkSnapshot<'a, Param0: ::windows::core::IntoParam<'a, HPSS>, Param2: ::windows::core::IntoParam<'a, HPSSWALK>>(snapshothandle: Param0, informationclass: PSS_WALK_INFORMATION_CLASS, walkmarkerhandle: Param2, buffer: *mut ::core::ffi::c_void, bufferlength: u32) -> u32 {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
             fn PssWalkSnapshot(snapshothandle: HPSS, informationclass: PSS_WALK_INFORMATION_CLASS, walkmarkerhandle: HPSSWALK, buffer: *mut ::core::ffi::c_void, bufferlength: u32) -> u32;
         }
-        ::core::mem::transmute(PssWalkSnapshot(snapshothandle.into_param().abi(), ::core::mem::transmute(informationclass), walkmarkerhandle.into_param().abi(), ::core::mem::transmute(::windows::core::as_mut_ptr_or_null(buffer)), buffer.len() as _))
+        ::core::mem::transmute(PssWalkSnapshot(snapshothandle.into_param().abi(), ::core::mem::transmute(informationclass), walkmarkerhandle.into_param().abi(), ::core::mem::transmute(buffer), ::core::mem::transmute(bufferlength)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
