@@ -1,9 +1,9 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
 #[repr(transparent)]
 pub struct IInkCommitRequestHandler(::windows::core::IUnknown);
 impl IInkCommitRequestHandler {
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn OnCommitRequested(&self) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).OnCommitRequested)(::core::mem::transmute_copy(self)).ok()
     }
@@ -23,7 +23,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IInkCommi
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IInkCommitRequestHandler {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IInkCommitRequestHandler {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -54,11 +54,11 @@ pub struct IInkCommitRequestHandler_Vtbl {
     pub base: ::windows::core::IUnknownVtbl,
     pub OnCommitRequested: unsafe extern "system" fn(this: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
 #[repr(transparent)]
 pub struct IInkD2DRenderer(::windows::core::IUnknown);
 impl IInkD2DRenderer {
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`, `\"Win32_Foundation\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink', 'Win32_Foundation'*"]
     #[cfg(feature = "Win32_Foundation")]
     pub unsafe fn Draw<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::IUnknown>, Param1: ::windows::core::IntoParam<'a, ::windows::core::IUnknown>, Param2: ::windows::core::IntoParam<'a, super::super::super::Foundation::BOOL>>(&self, pd2d1devicecontext: Param0, pinkstrokeiterable: Param1, fhighcontrast: Param2) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).Draw)(::core::mem::transmute_copy(self), pd2d1devicecontext.into_param().abi(), pinkstrokeiterable.into_param().abi(), fhighcontrast.into_param().abi()).ok()
@@ -79,7 +79,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IInkD2DRe
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IInkD2DRenderer {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IInkD2DRenderer {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -113,11 +113,11 @@ pub struct IInkD2DRenderer_Vtbl {
     #[cfg(not(feature = "Win32_Foundation"))]
     Draw: usize,
 }
-#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
 #[repr(transparent)]
 pub struct IInkD2DRenderer2(::windows::core::IUnknown);
 impl IInkD2DRenderer2 {
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn Draw<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::IUnknown>, Param1: ::windows::core::IntoParam<'a, ::windows::core::IUnknown>>(&self, pd2d1devicecontext: Param0, pinkstrokeiterable: Param1, highcontrastadjustment: INK_HIGH_CONTRAST_ADJUSTMENT) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).Draw)(::core::mem::transmute_copy(self), pd2d1devicecontext.into_param().abi(), pinkstrokeiterable.into_param().abi(), ::core::mem::transmute(highcontrastadjustment)).ok()
     }
@@ -137,7 +137,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IInkD2DRe
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IInkD2DRenderer2 {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IInkD2DRenderer2 {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -168,20 +168,20 @@ pub struct IInkD2DRenderer2_Vtbl {
     pub base: ::windows::core::IUnknownVtbl,
     pub Draw: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, pd2d1devicecontext: *mut ::core::ffi::c_void, pinkstrokeiterable: *mut ::core::ffi::c_void, highcontrastadjustment: INK_HIGH_CONTRAST_ADJUSTMENT) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
 #[repr(transparent)]
 pub struct IInkDesktopHost(::windows::core::IUnknown);
 impl IInkDesktopHost {
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn QueueWorkItem<'a, Param0: ::windows::core::IntoParam<'a, IInkHostWorkItem>>(&self, workitem: Param0) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).QueueWorkItem)(::core::mem::transmute_copy(self), workitem.into_param().abi()).ok()
     }
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn CreateInkPresenter<T: ::windows::core::Interface>(&self) -> ::windows::core::Result<T> {
         let mut result__ = ::core::option::Option::None;
         (::windows::core::Interface::vtable(self).CreateInkPresenter)(::core::mem::transmute_copy(self), &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
     }
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn CreateAndInitializeInkPresenter<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::IUnknown>, T: ::windows::core::Interface>(&self, rootvisual: Param0, width: f32, height: f32) -> ::windows::core::Result<T> {
         let mut result__ = ::core::option::Option::None;
         (::windows::core::Interface::vtable(self).CreateAndInitializeInkPresenter)(::core::mem::transmute_copy(self), rootvisual.into_param().abi(), ::core::mem::transmute(width), ::core::mem::transmute(height), &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
@@ -202,7 +202,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IInkDeskt
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IInkDesktopHost {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IInkDesktopHost {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -235,11 +235,11 @@ pub struct IInkDesktopHost_Vtbl {
     pub CreateInkPresenter: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, riid: *const ::windows::core::GUID, ppv: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
     pub CreateAndInitializeInkPresenter: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, rootvisual: *mut ::core::ffi::c_void, width: f32, height: f32, riid: *const ::windows::core::GUID, ppv: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
 #[repr(transparent)]
 pub struct IInkHostWorkItem(::windows::core::IUnknown);
 impl IInkHostWorkItem {
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn Invoke(&self) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).Invoke)(::core::mem::transmute_copy(self)).ok()
     }
@@ -259,7 +259,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IInkHostW
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IInkHostWorkItem {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IInkHostWorkItem {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -290,27 +290,27 @@ pub struct IInkHostWorkItem_Vtbl {
     pub base: ::windows::core::IUnknownVtbl,
     pub Invoke: unsafe extern "system" fn(this: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
 #[repr(transparent)]
 pub struct IInkPresenterDesktop(::windows::core::IUnknown);
 impl IInkPresenterDesktop {
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn SetRootVisual<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::IUnknown>, Param1: ::windows::core::IntoParam<'a, ::windows::core::IUnknown>>(&self, rootvisual: Param0, device: Param1) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).SetRootVisual)(::core::mem::transmute_copy(self), rootvisual.into_param().abi(), device.into_param().abi()).ok()
     }
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn SetCommitRequestHandler<'a, Param0: ::windows::core::IntoParam<'a, IInkCommitRequestHandler>>(&self, handler: Param0) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).SetCommitRequestHandler)(::core::mem::transmute_copy(self), handler.into_param().abi()).ok()
     }
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn GetSize(&self, width: *mut f32, height: *mut f32) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).GetSize)(::core::mem::transmute_copy(self), ::core::mem::transmute(width), ::core::mem::transmute(height)).ok()
     }
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn SetSize(&self, width: f32, height: f32) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).SetSize)(::core::mem::transmute_copy(self), ::core::mem::transmute(width), ::core::mem::transmute(height)).ok()
     }
-    #[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+    #[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
     pub unsafe fn OnHighContrastChanged(&self) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).OnHighContrastChanged)(::core::mem::transmute_copy(self)).ok()
     }
@@ -330,7 +330,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IInkPrese
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IInkPresenterDesktop {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IInkPresenterDesktop {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -365,15 +365,15 @@ pub struct IInkPresenterDesktop_Vtbl {
     pub SetSize: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, width: f32, height: f32) -> ::windows::core::HRESULT,
     pub OnHighContrastChanged: unsafe extern "system" fn(this: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct INK_HIGH_CONTRAST_ADJUSTMENT(pub i32);
-#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
 pub const USE_SYSTEM_COLORS_WHEN_NECESSARY: INK_HIGH_CONTRAST_ADJUSTMENT = INK_HIGH_CONTRAST_ADJUSTMENT(0i32);
-#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
 pub const USE_SYSTEM_COLORS: INK_HIGH_CONTRAST_ADJUSTMENT = INK_HIGH_CONTRAST_ADJUSTMENT(1i32);
-#[doc = "*Required features: `\"Win32_UI_Input_Ink\"`*"]
+#[doc = "*Required features: 'Win32_UI_Input_Ink'*"]
 pub const USE_ORIGINAL_COLORS: INK_HIGH_CONTRAST_ADJUSTMENT = INK_HIGH_CONTRAST_ADJUSTMENT(2i32);
 impl ::core::marker::Copy for INK_HIGH_CONTRAST_ADJUSTMENT {}
 impl ::core::clone::Clone for INK_HIGH_CONTRAST_ADJUSTMENT {
