@@ -1,5 +1,5 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[doc = "*Required features: 'Graphics_Display_Core'*"]
+#[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HdmiDisplayColorSpace(pub i32);
@@ -30,12 +30,13 @@ impl ::core::fmt::Debug for HdmiDisplayColorSpace {
 }
 unsafe impl ::windows::core::RuntimeType for HdmiDisplayColorSpace {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Graphics.Display.Core.HdmiDisplayColorSpace;i4)");
-}
-impl ::windows::core::DefaultType for HdmiDisplayColorSpace {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Graphics_Display_Core'*"]
+#[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
 pub struct HdmiDisplayHdr2086Metadata {
     pub RedPrimaryX: u16,
     pub RedPrimaryY: u16,
@@ -79,9 +80,10 @@ unsafe impl ::windows::core::Abi for HdmiDisplayHdr2086Metadata {
 }
 unsafe impl ::windows::core::RuntimeType for HdmiDisplayHdr2086Metadata {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"struct(Windows.Graphics.Display.Core.HdmiDisplayHdr2086Metadata;u2;u2;u2;u2;u2;u2;u2;u2;u2;u2;u2;u2)");
-}
-impl ::windows::core::DefaultType for HdmiDisplayHdr2086Metadata {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
 impl ::core::cmp::PartialEq for HdmiDisplayHdr2086Metadata {
     fn eq(&self, other: &Self) -> bool {
@@ -94,7 +96,7 @@ impl ::core::default::Default for HdmiDisplayHdr2086Metadata {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Graphics_Display_Core'*"]
+#[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HdmiDisplayHdrOption(pub i32);
@@ -125,15 +127,16 @@ impl ::core::fmt::Debug for HdmiDisplayHdrOption {
 }
 unsafe impl ::windows::core::RuntimeType for HdmiDisplayHdrOption {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Graphics.Display.Core.HdmiDisplayHdrOption;i4)");
-}
-impl ::windows::core::DefaultType for HdmiDisplayHdrOption {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
-#[doc = "*Required features: 'Graphics_Display_Core'*"]
+#[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
 #[repr(transparent)]
 pub struct HdmiDisplayInformation(::windows::core::IUnknown);
 impl HdmiDisplayInformation {
-    #[doc = "*Required features: 'Graphics_Display_Core', 'Foundation_Collections'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`, `\"Foundation_Collections\"`*"]
     #[cfg(feature = "Foundation_Collections")]
     pub fn GetSupportedDisplayModes(&self) -> ::windows::core::Result<super::super::super::Foundation::Collections::IVectorView<HdmiDisplayMode>> {
         let this = self;
@@ -142,7 +145,7 @@ impl HdmiDisplayInformation {
             (::windows::core::Interface::vtable(this).GetSupportedDisplayModes)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::Collections::IVectorView<HdmiDisplayMode>>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn GetCurrentDisplayMode(&self) -> ::windows::core::Result<HdmiDisplayMode> {
         let this = self;
         unsafe {
@@ -150,7 +153,7 @@ impl HdmiDisplayInformation {
             (::windows::core::Interface::vtable(this).GetCurrentDisplayMode)(::core::mem::transmute_copy(this), &mut result__).from_abi::<HdmiDisplayMode>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core', 'Foundation'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn SetDefaultDisplayModeAsync(&self) -> ::windows::core::Result<super::super::super::Foundation::IAsyncAction> {
         let this = self;
@@ -159,7 +162,7 @@ impl HdmiDisplayInformation {
             (::windows::core::Interface::vtable(this).SetDefaultDisplayModeAsync)(::core::mem::transmute_copy(this), &mut result__).from_abi::<super::super::super::Foundation::IAsyncAction>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core', 'Foundation'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn RequestSetCurrentDisplayModeAsync<'a, Param0: ::windows::core::IntoParam<'a, HdmiDisplayMode>>(&self, mode: Param0) -> ::windows::core::Result<super::super::super::Foundation::IAsyncOperation<bool>> {
         let this = self;
@@ -168,7 +171,7 @@ impl HdmiDisplayInformation {
             (::windows::core::Interface::vtable(this).RequestSetCurrentDisplayModeAsync)(::core::mem::transmute_copy(this), mode.into_param().abi(), &mut result__).from_abi::<super::super::super::Foundation::IAsyncOperation<bool>>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core', 'Foundation'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn RequestSetCurrentDisplayModeWithHdrAsync<'a, Param0: ::windows::core::IntoParam<'a, HdmiDisplayMode>>(&self, mode: Param0, hdroption: HdmiDisplayHdrOption) -> ::windows::core::Result<super::super::super::Foundation::IAsyncOperation<bool>> {
         let this = self;
@@ -177,7 +180,7 @@ impl HdmiDisplayInformation {
             (::windows::core::Interface::vtable(this).RequestSetCurrentDisplayModeWithHdrAsync)(::core::mem::transmute_copy(this), mode.into_param().abi(), hdroption, &mut result__).from_abi::<super::super::super::Foundation::IAsyncOperation<bool>>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core', 'Foundation'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn RequestSetCurrentDisplayModeWithHdrAndMetadataAsync<'a, Param0: ::windows::core::IntoParam<'a, HdmiDisplayMode>, Param2: ::windows::core::IntoParam<'a, HdmiDisplayHdr2086Metadata>>(&self, mode: Param0, hdroption: HdmiDisplayHdrOption, hdrmetadata: Param2) -> ::windows::core::Result<super::super::super::Foundation::IAsyncOperation<bool>> {
         let this = self;
@@ -186,7 +189,7 @@ impl HdmiDisplayInformation {
             (::windows::core::Interface::vtable(this).RequestSetCurrentDisplayModeWithHdrAndMetadataAsync)(::core::mem::transmute_copy(this), mode.into_param().abi(), hdroption, hdrmetadata.into_param().abi(), &mut result__).from_abi::<super::super::super::Foundation::IAsyncOperation<bool>>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core', 'Foundation'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn DisplayModesChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::TypedEventHandler<HdmiDisplayInformation, ::windows::core::IInspectable>>>(&self, value: Param0) -> ::windows::core::Result<super::super::super::Foundation::EventRegistrationToken> {
         let this = self;
@@ -195,13 +198,13 @@ impl HdmiDisplayInformation {
             (::windows::core::Interface::vtable(this).DisplayModesChanged)(::core::mem::transmute_copy(this), value.into_param().abi(), &mut result__).from_abi::<super::super::super::Foundation::EventRegistrationToken>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core', 'Foundation'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`, `\"Foundation\"`*"]
     #[cfg(feature = "Foundation")]
     pub fn RemoveDisplayModesChanged<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::EventRegistrationToken>>(&self, token: Param0) -> ::windows::core::Result<()> {
         let this = self;
         unsafe { (::windows::core::Interface::vtable(this).RemoveDisplayModesChanged)(::core::mem::transmute_copy(this), token.into_param().abi()).ok() }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn GetForCurrentView() -> ::windows::core::Result<HdmiDisplayInformation> {
         Self::IHdmiDisplayInformationStatics(|this| unsafe {
             let mut result__: ::windows::core::RawPtr = ::core::mem::zeroed();
@@ -232,6 +235,10 @@ impl ::core::fmt::Debug for HdmiDisplayInformation {
 }
 unsafe impl ::windows::core::RuntimeType for HdmiDisplayInformation {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Graphics.Display.Core.HdmiDisplayInformation;{130b3c0a-f565-476e-abd5-ea05aee74c69})");
+    type DefaultType = ::core::option::Option<Self>;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+    }
 }
 unsafe impl ::windows::core::Interface for HdmiDisplayInformation {
     type Vtable = IHdmiDisplayInformation_Vtbl;
@@ -255,7 +262,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for HdmiDispl
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &HdmiDisplayInformation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a HdmiDisplayInformation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -275,18 +282,18 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for HdmiD
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &HdmiDisplayInformation {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a HdmiDisplayInformation {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for HdmiDisplayInformation {}
 unsafe impl ::core::marker::Sync for HdmiDisplayInformation {}
-#[doc = "*Required features: 'Graphics_Display_Core'*"]
+#[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
 #[repr(transparent)]
 pub struct HdmiDisplayMode(::windows::core::IUnknown);
 impl HdmiDisplayMode {
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn ResolutionWidthInRawPixels(&self) -> ::windows::core::Result<u32> {
         let this = self;
         unsafe {
@@ -294,7 +301,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).ResolutionWidthInRawPixels)(::core::mem::transmute_copy(this), &mut result__).from_abi::<u32>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn ResolutionHeightInRawPixels(&self) -> ::windows::core::Result<u32> {
         let this = self;
         unsafe {
@@ -302,7 +309,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).ResolutionHeightInRawPixels)(::core::mem::transmute_copy(this), &mut result__).from_abi::<u32>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn RefreshRate(&self) -> ::windows::core::Result<f64> {
         let this = self;
         unsafe {
@@ -310,7 +317,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).RefreshRate)(::core::mem::transmute_copy(this), &mut result__).from_abi::<f64>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn StereoEnabled(&self) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -318,7 +325,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).StereoEnabled)(::core::mem::transmute_copy(this), &mut result__).from_abi::<bool>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn BitsPerPixel(&self) -> ::windows::core::Result<u16> {
         let this = self;
         unsafe {
@@ -326,7 +333,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).BitsPerPixel)(::core::mem::transmute_copy(this), &mut result__).from_abi::<u16>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn IsEqual<'a, Param0: ::windows::core::IntoParam<'a, HdmiDisplayMode>>(&self, mode: Param0) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -334,7 +341,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).IsEqual)(::core::mem::transmute_copy(this), mode.into_param().abi(), &mut result__).from_abi::<bool>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn ColorSpace(&self) -> ::windows::core::Result<HdmiDisplayColorSpace> {
         let this = self;
         unsafe {
@@ -342,7 +349,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).ColorSpace)(::core::mem::transmute_copy(this), &mut result__).from_abi::<HdmiDisplayColorSpace>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn PixelEncoding(&self) -> ::windows::core::Result<HdmiDisplayPixelEncoding> {
         let this = self;
         unsafe {
@@ -350,7 +357,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).PixelEncoding)(::core::mem::transmute_copy(this), &mut result__).from_abi::<HdmiDisplayPixelEncoding>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn IsSdrLuminanceSupported(&self) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -358,7 +365,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).IsSdrLuminanceSupported)(::core::mem::transmute_copy(this), &mut result__).from_abi::<bool>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn IsSmpte2084Supported(&self) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -366,7 +373,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).IsSmpte2084Supported)(::core::mem::transmute_copy(this), &mut result__).from_abi::<bool>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn Is2086MetadataSupported(&self) -> ::windows::core::Result<bool> {
         let this = self;
         unsafe {
@@ -374,7 +381,7 @@ impl HdmiDisplayMode {
             (::windows::core::Interface::vtable(this).Is2086MetadataSupported)(::core::mem::transmute_copy(this), &mut result__).from_abi::<bool>(result__)
         }
     }
-    #[doc = "*Required features: 'Graphics_Display_Core'*"]
+    #[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
     pub fn IsDolbyVisionLowLatencySupported(&self) -> ::windows::core::Result<bool> {
         let this = &::windows::core::Interface::cast::<IHdmiDisplayMode2>(self)?;
         unsafe {
@@ -401,6 +408,10 @@ impl ::core::fmt::Debug for HdmiDisplayMode {
 }
 unsafe impl ::windows::core::RuntimeType for HdmiDisplayMode {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"rc(Windows.Graphics.Display.Core.HdmiDisplayMode;{0c06d5ad-1b90-4f51-9981-ef5a1c0ddf66})");
+    type DefaultType = ::core::option::Option<Self>;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        from.as_ref().cloned().ok_or(::windows::core::Error::OK)
+    }
 }
 unsafe impl ::windows::core::Interface for HdmiDisplayMode {
     type Vtable = IHdmiDisplayMode_Vtbl;
@@ -424,7 +435,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for HdmiDispl
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &HdmiDisplayMode {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a HdmiDisplayMode {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -444,14 +455,14 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for HdmiD
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &HdmiDisplayMode {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IInspectable> for &'a HdmiDisplayMode {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IInspectable> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
 }
 unsafe impl ::core::marker::Send for HdmiDisplayMode {}
 unsafe impl ::core::marker::Sync for HdmiDisplayMode {}
-#[doc = "*Required features: 'Graphics_Display_Core'*"]
+#[doc = "*Required features: `\"Graphics_Display_Core\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HdmiDisplayPixelEncoding(pub i32);
@@ -482,9 +493,10 @@ impl ::core::fmt::Debug for HdmiDisplayPixelEncoding {
 }
 unsafe impl ::windows::core::RuntimeType for HdmiDisplayPixelEncoding {
     const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Graphics.Display.Core.HdmiDisplayPixelEncoding;i4)");
-}
-impl ::windows::core::DefaultType for HdmiDisplayPixelEncoding {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> ::windows::core::Result<Self> {
+        Ok(*from)
+    }
 }
 #[doc(hidden)]
 #[repr(transparent)]
