@@ -1,16 +1,16 @@
 pub trait ITraceEvent_Impl: Sized {
-    fn Clone(&mut self) -> ::windows::core::Result<ITraceEvent>;
-    fn GetUserContext(&mut self, usercontext: *mut *mut ::core::ffi::c_void) -> ::windows::core::Result<()>;
-    fn GetEventRecord(&mut self) -> ::windows::core::Result<*mut EVENT_RECORD>;
-    fn SetPayload(&mut self, payload: *const u8, payloadsize: u32) -> ::windows::core::Result<()>;
-    fn SetEventDescriptor(&mut self, eventdescriptor: *const EVENT_DESCRIPTOR) -> ::windows::core::Result<()>;
-    fn SetProcessId(&mut self, processid: u32) -> ::windows::core::Result<()>;
-    fn SetProcessorIndex(&mut self, processorindex: u32) -> ::windows::core::Result<()>;
-    fn SetThreadId(&mut self, threadid: u32) -> ::windows::core::Result<()>;
-    fn SetThreadTimes(&mut self, kerneltime: u32, usertime: u32) -> ::windows::core::Result<()>;
-    fn SetActivityId(&mut self, activityid: *const ::windows::core::GUID) -> ::windows::core::Result<()>;
-    fn SetTimeStamp(&mut self, timestamp: *const i64) -> ::windows::core::Result<()>;
-    fn SetProviderId(&mut self, providerid: *const ::windows::core::GUID) -> ::windows::core::Result<()>;
+    fn Clone(&self) -> ::windows::core::Result<ITraceEvent>;
+    fn GetUserContext(&self) -> ::windows::core::Result<*mut ::core::ffi::c_void>;
+    fn GetEventRecord(&self) -> ::windows::core::Result<*mut EVENT_RECORD>;
+    fn SetPayload(&self, payload: *const u8, payloadsize: u32) -> ::windows::core::Result<()>;
+    fn SetEventDescriptor(&self, eventdescriptor: *const EVENT_DESCRIPTOR) -> ::windows::core::Result<()>;
+    fn SetProcessId(&self, processid: u32) -> ::windows::core::Result<()>;
+    fn SetProcessorIndex(&self, processorindex: u32) -> ::windows::core::Result<()>;
+    fn SetThreadId(&self, threadid: u32) -> ::windows::core::Result<()>;
+    fn SetThreadTimes(&self, kerneltime: u32, usertime: u32) -> ::windows::core::Result<()>;
+    fn SetActivityId(&self, activityid: *const ::windows::core::GUID) -> ::windows::core::Result<()>;
+    fn SetTimeStamp(&self, timestamp: *const i64) -> ::windows::core::Result<()>;
+    fn SetProviderId(&self, providerid: *const ::windows::core::GUID) -> ::windows::core::Result<()>;
 }
 impl ITraceEvent_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl, Impl: ITraceEvent_Impl, const OFFSET: isize>() -> ITraceEvent_Vtbl {
@@ -28,7 +28,13 @@ impl ITraceEvent_Vtbl {
         unsafe extern "system" fn GetUserContext<Identity: ::windows::core::IUnknownImpl, Impl: ITraceEvent_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, usercontext: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            (*this).GetUserContext(::core::mem::transmute_copy(&usercontext)).into()
+            match (*this).GetUserContext() {
+                ::core::result::Result::Ok(ok__) => {
+                    *usercontext = ::core::mem::transmute(ok__);
+                    ::windows::core::HRESULT(0)
+                }
+                ::core::result::Result::Err(err) => err.into(),
+            }
         }
         unsafe extern "system" fn GetEventRecord<Identity: ::windows::core::IUnknownImpl, Impl: ITraceEvent_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, eventrecord: *mut *mut EVENT_RECORD) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
@@ -107,9 +113,9 @@ impl ITraceEvent_Vtbl {
     }
 }
 pub trait ITraceEventCallback_Impl: Sized {
-    fn OnBeginProcessTrace(&mut self, headerevent: &::core::option::Option<ITraceEvent>, relogger: &::core::option::Option<ITraceRelogger>) -> ::windows::core::Result<()>;
-    fn OnFinalizeProcessTrace(&mut self, relogger: &::core::option::Option<ITraceRelogger>) -> ::windows::core::Result<()>;
-    fn OnEvent(&mut self, event: &::core::option::Option<ITraceEvent>, relogger: &::core::option::Option<ITraceRelogger>) -> ::windows::core::Result<()>;
+    fn OnBeginProcessTrace(&self, headerevent: &::core::option::Option<ITraceEvent>, relogger: &::core::option::Option<ITraceRelogger>) -> ::windows::core::Result<()>;
+    fn OnFinalizeProcessTrace(&self, relogger: &::core::option::Option<ITraceRelogger>) -> ::windows::core::Result<()>;
+    fn OnEvent(&self, event: &::core::option::Option<ITraceEvent>, relogger: &::core::option::Option<ITraceRelogger>) -> ::windows::core::Result<()>;
 }
 impl ITraceEventCallback_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl, Impl: ITraceEventCallback_Impl, const OFFSET: isize>() -> ITraceEventCallback_Vtbl {
@@ -141,15 +147,15 @@ impl ITraceEventCallback_Vtbl {
 }
 #[cfg(feature = "Win32_Foundation")]
 pub trait ITraceRelogger_Impl: Sized {
-    fn AddLogfileTraceStream(&mut self, logfilename: &super::super::super::Foundation::BSTR, usercontext: *const ::core::ffi::c_void) -> ::windows::core::Result<u64>;
-    fn AddRealtimeTraceStream(&mut self, loggername: &super::super::super::Foundation::BSTR, usercontext: *const ::core::ffi::c_void) -> ::windows::core::Result<u64>;
-    fn RegisterCallback(&mut self, callback: &::core::option::Option<ITraceEventCallback>) -> ::windows::core::Result<()>;
-    fn Inject(&mut self, event: &::core::option::Option<ITraceEvent>) -> ::windows::core::Result<()>;
-    fn CreateEventInstance(&mut self, tracehandle: u64, flags: u32) -> ::windows::core::Result<ITraceEvent>;
-    fn ProcessTrace(&mut self) -> ::windows::core::Result<()>;
-    fn SetOutputFilename(&mut self, logfilename: &super::super::super::Foundation::BSTR) -> ::windows::core::Result<()>;
-    fn SetCompressionMode(&mut self, compressionmode: super::super::super::Foundation::BOOLEAN) -> ::windows::core::Result<()>;
-    fn Cancel(&mut self) -> ::windows::core::Result<()>;
+    fn AddLogfileTraceStream(&self, logfilename: &super::super::super::Foundation::BSTR, usercontext: *const ::core::ffi::c_void) -> ::windows::core::Result<u64>;
+    fn AddRealtimeTraceStream(&self, loggername: &super::super::super::Foundation::BSTR, usercontext: *const ::core::ffi::c_void) -> ::windows::core::Result<u64>;
+    fn RegisterCallback(&self, callback: &::core::option::Option<ITraceEventCallback>) -> ::windows::core::Result<()>;
+    fn Inject(&self, event: &::core::option::Option<ITraceEvent>) -> ::windows::core::Result<()>;
+    fn CreateEventInstance(&self, tracehandle: u64, flags: u32) -> ::windows::core::Result<ITraceEvent>;
+    fn ProcessTrace(&self) -> ::windows::core::Result<()>;
+    fn SetOutputFilename(&self, logfilename: &super::super::super::Foundation::BSTR) -> ::windows::core::Result<()>;
+    fn SetCompressionMode(&self, compressionmode: super::super::super::Foundation::BOOLEAN) -> ::windows::core::Result<()>;
+    fn Cancel(&self) -> ::windows::core::Result<()>;
 }
 #[cfg(feature = "Win32_Foundation")]
 impl ITraceRelogger_Vtbl {
@@ -157,7 +163,7 @@ impl ITraceRelogger_Vtbl {
         unsafe extern "system" fn AddLogfileTraceStream<Identity: ::windows::core::IUnknownImpl, Impl: ITraceRelogger_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, logfilename: ::core::mem::ManuallyDrop<super::super::super::Foundation::BSTR>, usercontext: *const ::core::ffi::c_void, tracehandle: *mut u64) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            match (*this).AddLogfileTraceStream(::core::mem::transmute_copy(&logfilename), ::core::mem::transmute_copy(&usercontext)) {
+            match (*this).AddLogfileTraceStream(::core::mem::transmute(&logfilename), ::core::mem::transmute_copy(&usercontext)) {
                 ::core::result::Result::Ok(ok__) => {
                     *tracehandle = ::core::mem::transmute(ok__);
                     ::windows::core::HRESULT(0)
@@ -168,7 +174,7 @@ impl ITraceRelogger_Vtbl {
         unsafe extern "system" fn AddRealtimeTraceStream<Identity: ::windows::core::IUnknownImpl, Impl: ITraceRelogger_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, loggername: ::core::mem::ManuallyDrop<super::super::super::Foundation::BSTR>, usercontext: *const ::core::ffi::c_void, tracehandle: *mut u64) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            match (*this).AddRealtimeTraceStream(::core::mem::transmute_copy(&loggername), ::core::mem::transmute_copy(&usercontext)) {
+            match (*this).AddRealtimeTraceStream(::core::mem::transmute(&loggername), ::core::mem::transmute_copy(&usercontext)) {
                 ::core::result::Result::Ok(ok__) => {
                     *tracehandle = ::core::mem::transmute(ok__);
                     ::windows::core::HRESULT(0)
@@ -205,7 +211,7 @@ impl ITraceRelogger_Vtbl {
         unsafe extern "system" fn SetOutputFilename<Identity: ::windows::core::IUnknownImpl, Impl: ITraceRelogger_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, logfilename: ::core::mem::ManuallyDrop<super::super::super::Foundation::BSTR>) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            (*this).SetOutputFilename(::core::mem::transmute_copy(&logfilename)).into()
+            (*this).SetOutputFilename(::core::mem::transmute(&logfilename)).into()
         }
         unsafe extern "system" fn SetCompressionMode<Identity: ::windows::core::IUnknownImpl, Impl: ITraceRelogger_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, compressionmode: super::super::super::Foundation::BOOLEAN) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
