@@ -1,6 +1,6 @@
 #[cfg(feature = "Win32_Foundation")]
 pub trait IWPCGamesSettings_Impl: Sized + IWPCSettings_Impl {
-    fn IsBlocked(&mut self, guidappid: &::windows::core::GUID) -> ::windows::core::Result<u32>;
+    fn IsBlocked(&self, guidappid: &::windows::core::GUID) -> ::windows::core::Result<u32>;
 }
 #[cfg(feature = "Win32_Foundation")]
 impl IWPCGamesSettings_Vtbl {
@@ -8,7 +8,7 @@ impl IWPCGamesSettings_Vtbl {
         unsafe extern "system" fn IsBlocked<Identity: ::windows::core::IUnknownImpl, Impl: IWPCGamesSettings_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, guidappid: ::windows::core::GUID, pdwreasons: *mut u32) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            match (*this).IsBlocked(::core::mem::transmute_copy(&guidappid)) {
+            match (*this).IsBlocked(::core::mem::transmute(&guidappid)) {
                 ::core::result::Result::Ok(ok__) => {
                     *pdwreasons = ::core::mem::transmute(ok__);
                     ::windows::core::HRESULT(0)
@@ -24,9 +24,9 @@ impl IWPCGamesSettings_Vtbl {
 }
 #[cfg(feature = "Win32_Foundation")]
 pub trait IWPCProviderConfig_Impl: Sized {
-    fn GetUserSummary(&mut self, bstrsid: &super::super::Foundation::BSTR) -> ::windows::core::Result<super::super::Foundation::BSTR>;
-    fn Configure(&mut self, hwnd: super::super::Foundation::HWND, bstrsid: &super::super::Foundation::BSTR) -> ::windows::core::Result<()>;
-    fn RequestOverride(&mut self, hwnd: super::super::Foundation::HWND, bstrpath: &super::super::Foundation::BSTR, dwflags: WPCFLAG_RESTRICTION) -> ::windows::core::Result<()>;
+    fn GetUserSummary(&self, bstrsid: &super::super::Foundation::BSTR) -> ::windows::core::Result<super::super::Foundation::BSTR>;
+    fn Configure(&self, hwnd: super::super::Foundation::HWND, bstrsid: &super::super::Foundation::BSTR) -> ::windows::core::Result<()>;
+    fn RequestOverride(&self, hwnd: super::super::Foundation::HWND, bstrpath: &super::super::Foundation::BSTR, dwflags: WPCFLAG_RESTRICTION) -> ::windows::core::Result<()>;
 }
 #[cfg(feature = "Win32_Foundation")]
 impl IWPCProviderConfig_Vtbl {
@@ -34,7 +34,7 @@ impl IWPCProviderConfig_Vtbl {
         unsafe extern "system" fn GetUserSummary<Identity: ::windows::core::IUnknownImpl, Impl: IWPCProviderConfig_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, bstrsid: ::core::mem::ManuallyDrop<super::super::Foundation::BSTR>, pbstrusersummary: *mut super::super::Foundation::BSTR) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            match (*this).GetUserSummary(::core::mem::transmute_copy(&bstrsid)) {
+            match (*this).GetUserSummary(::core::mem::transmute(&bstrsid)) {
                 ::core::result::Result::Ok(ok__) => {
                     *pbstrusersummary = ::core::mem::transmute(ok__);
                     ::windows::core::HRESULT(0)
@@ -45,12 +45,12 @@ impl IWPCProviderConfig_Vtbl {
         unsafe extern "system" fn Configure<Identity: ::windows::core::IUnknownImpl, Impl: IWPCProviderConfig_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, hwnd: super::super::Foundation::HWND, bstrsid: ::core::mem::ManuallyDrop<super::super::Foundation::BSTR>) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            (*this).Configure(::core::mem::transmute_copy(&hwnd), ::core::mem::transmute_copy(&bstrsid)).into()
+            (*this).Configure(::core::mem::transmute_copy(&hwnd), ::core::mem::transmute(&bstrsid)).into()
         }
         unsafe extern "system" fn RequestOverride<Identity: ::windows::core::IUnknownImpl, Impl: IWPCProviderConfig_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, hwnd: super::super::Foundation::HWND, bstrpath: ::core::mem::ManuallyDrop<super::super::Foundation::BSTR>, dwflags: WPCFLAG_RESTRICTION) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            (*this).RequestOverride(::core::mem::transmute_copy(&hwnd), ::core::mem::transmute_copy(&bstrpath), ::core::mem::transmute_copy(&dwflags)).into()
+            (*this).RequestOverride(::core::mem::transmute_copy(&hwnd), ::core::mem::transmute(&bstrpath), ::core::mem::transmute_copy(&dwflags)).into()
         }
         Self {
             base: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
@@ -64,8 +64,8 @@ impl IWPCProviderConfig_Vtbl {
     }
 }
 pub trait IWPCProviderState_Impl: Sized {
-    fn Enable(&mut self) -> ::windows::core::Result<()>;
-    fn Disable(&mut self) -> ::windows::core::Result<()>;
+    fn Enable(&self) -> ::windows::core::Result<()>;
+    fn Disable(&self) -> ::windows::core::Result<()>;
 }
 impl IWPCProviderState_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl, Impl: IWPCProviderState_Impl, const OFFSET: isize>() -> IWPCProviderState_Vtbl {
@@ -90,7 +90,7 @@ impl IWPCProviderState_Vtbl {
     }
 }
 pub trait IWPCProviderSupport_Impl: Sized {
-    fn GetCurrent(&mut self) -> ::windows::core::Result<::windows::core::GUID>;
+    fn GetCurrent(&self) -> ::windows::core::Result<::windows::core::GUID>;
 }
 impl IWPCProviderSupport_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl, Impl: IWPCProviderSupport_Impl, const OFFSET: isize>() -> IWPCProviderSupport_Vtbl {
@@ -113,9 +113,9 @@ impl IWPCProviderSupport_Vtbl {
 }
 #[cfg(feature = "Win32_Foundation")]
 pub trait IWPCSettings_Impl: Sized {
-    fn IsLoggingRequired(&mut self) -> ::windows::core::Result<super::super::Foundation::BOOL>;
-    fn GetLastSettingsChangeTime(&mut self) -> ::windows::core::Result<super::super::Foundation::SYSTEMTIME>;
-    fn GetRestrictions(&mut self) -> ::windows::core::Result<WPCFLAG_RESTRICTION>;
+    fn IsLoggingRequired(&self) -> ::windows::core::Result<super::super::Foundation::BOOL>;
+    fn GetLastSettingsChangeTime(&self) -> ::windows::core::Result<super::super::Foundation::SYSTEMTIME>;
+    fn GetRestrictions(&self) -> ::windows::core::Result<WPCFLAG_RESTRICTION>;
 }
 #[cfg(feature = "Win32_Foundation")]
 impl IWPCSettings_Vtbl {
@@ -166,8 +166,8 @@ impl IWPCSettings_Vtbl {
 }
 #[cfg(feature = "Win32_Foundation")]
 pub trait IWPCWebSettings_Impl: Sized + IWPCSettings_Impl {
-    fn GetSettings(&mut self) -> ::windows::core::Result<WPCFLAG_WEB_SETTING>;
-    fn RequestURLOverride(&mut self, hwnd: super::super::Foundation::HWND, pcszurl: super::super::Foundation::PWSTR, curls: u32, ppcszsuburls: *const super::super::Foundation::PWSTR) -> ::windows::core::Result<super::super::Foundation::BOOL>;
+    fn GetSettings(&self) -> ::windows::core::Result<WPCFLAG_WEB_SETTING>;
+    fn RequestURLOverride(&self, hwnd: super::super::Foundation::HWND, pcszurl: &::windows::core::PCWSTR, curls: u32, ppcszsuburls: *const ::windows::core::PWSTR) -> ::windows::core::Result<super::super::Foundation::BOOL>;
 }
 #[cfg(feature = "Win32_Foundation")]
 impl IWPCWebSettings_Vtbl {
@@ -183,10 +183,10 @@ impl IWPCWebSettings_Vtbl {
                 ::core::result::Result::Err(err) => err.into(),
             }
         }
-        unsafe extern "system" fn RequestURLOverride<Identity: ::windows::core::IUnknownImpl, Impl: IWPCWebSettings_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, hwnd: super::super::Foundation::HWND, pcszurl: super::super::Foundation::PWSTR, curls: u32, ppcszsuburls: *const super::super::Foundation::PWSTR, pfchanged: *mut super::super::Foundation::BOOL) -> ::windows::core::HRESULT {
+        unsafe extern "system" fn RequestURLOverride<Identity: ::windows::core::IUnknownImpl, Impl: IWPCWebSettings_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, hwnd: super::super::Foundation::HWND, pcszurl: ::windows::core::PCWSTR, curls: u32, ppcszsuburls: *const ::windows::core::PWSTR, pfchanged: *mut super::super::Foundation::BOOL) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            match (*this).RequestURLOverride(::core::mem::transmute_copy(&hwnd), ::core::mem::transmute_copy(&pcszurl), ::core::mem::transmute_copy(&curls), ::core::mem::transmute_copy(&ppcszsuburls)) {
+            match (*this).RequestURLOverride(::core::mem::transmute_copy(&hwnd), ::core::mem::transmute(&pcszurl), ::core::mem::transmute_copy(&curls), ::core::mem::transmute_copy(&ppcszsuburls)) {
                 ::core::result::Result::Ok(ok__) => {
                     *pfchanged = ::core::mem::transmute(ok__);
                     ::windows::core::HRESULT(0)
@@ -204,17 +204,15 @@ impl IWPCWebSettings_Vtbl {
         iid == &<IWPCWebSettings as ::windows::core::Interface>::IID || iid == &<IWPCSettings as ::windows::core::Interface>::IID
     }
 }
-#[cfg(feature = "Win32_Foundation")]
 pub trait IWindowsParentalControls_Impl: Sized + IWindowsParentalControlsCore_Impl {
-    fn GetGamesSettings(&mut self, pcszsid: super::super::Foundation::PWSTR) -> ::windows::core::Result<IWPCGamesSettings>;
+    fn GetGamesSettings(&self, pcszsid: &::windows::core::PCWSTR) -> ::windows::core::Result<IWPCGamesSettings>;
 }
-#[cfg(feature = "Win32_Foundation")]
 impl IWindowsParentalControls_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControls_Impl, const OFFSET: isize>() -> IWindowsParentalControls_Vtbl {
-        unsafe extern "system" fn GetGamesSettings<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControls_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pcszsid: super::super::Foundation::PWSTR, ppsettings: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT {
+        unsafe extern "system" fn GetGamesSettings<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControls_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pcszsid: ::windows::core::PCWSTR, ppsettings: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            match (*this).GetGamesSettings(::core::mem::transmute_copy(&pcszsid)) {
+            match (*this).GetGamesSettings(::core::mem::transmute(&pcszsid)) {
                 ::core::result::Result::Ok(ok__) => {
                     *ppsettings = ::core::mem::transmute(ok__);
                     ::windows::core::HRESULT(0)
@@ -228,14 +226,12 @@ impl IWindowsParentalControls_Vtbl {
         iid == &<IWindowsParentalControls as ::windows::core::Interface>::IID || iid == &<IWindowsParentalControlsCore as ::windows::core::Interface>::IID
     }
 }
-#[cfg(feature = "Win32_Foundation")]
 pub trait IWindowsParentalControlsCore_Impl: Sized {
-    fn GetVisibility(&mut self) -> ::windows::core::Result<WPCFLAG_VISIBILITY>;
-    fn GetUserSettings(&mut self, pcszsid: super::super::Foundation::PWSTR) -> ::windows::core::Result<IWPCSettings>;
-    fn GetWebSettings(&mut self, pcszsid: super::super::Foundation::PWSTR) -> ::windows::core::Result<IWPCWebSettings>;
-    fn GetWebFilterInfo(&mut self, pguidid: *mut ::windows::core::GUID, ppszname: *mut super::super::Foundation::PWSTR) -> ::windows::core::Result<()>;
+    fn GetVisibility(&self) -> ::windows::core::Result<WPCFLAG_VISIBILITY>;
+    fn GetUserSettings(&self, pcszsid: &::windows::core::PCWSTR) -> ::windows::core::Result<IWPCSettings>;
+    fn GetWebSettings(&self, pcszsid: &::windows::core::PCWSTR) -> ::windows::core::Result<IWPCWebSettings>;
+    fn GetWebFilterInfo(&self, pguidid: *mut ::windows::core::GUID, ppszname: *mut ::windows::core::PWSTR) -> ::windows::core::Result<()>;
 }
-#[cfg(feature = "Win32_Foundation")]
 impl IWindowsParentalControlsCore_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControlsCore_Impl, const OFFSET: isize>() -> IWindowsParentalControlsCore_Vtbl {
         unsafe extern "system" fn GetVisibility<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControlsCore_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pevisibility: *mut WPCFLAG_VISIBILITY) -> ::windows::core::HRESULT {
@@ -249,10 +245,10 @@ impl IWindowsParentalControlsCore_Vtbl {
                 ::core::result::Result::Err(err) => err.into(),
             }
         }
-        unsafe extern "system" fn GetUserSettings<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControlsCore_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pcszsid: super::super::Foundation::PWSTR, ppsettings: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT {
+        unsafe extern "system" fn GetUserSettings<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControlsCore_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pcszsid: ::windows::core::PCWSTR, ppsettings: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            match (*this).GetUserSettings(::core::mem::transmute_copy(&pcszsid)) {
+            match (*this).GetUserSettings(::core::mem::transmute(&pcszsid)) {
                 ::core::result::Result::Ok(ok__) => {
                     *ppsettings = ::core::mem::transmute(ok__);
                     ::windows::core::HRESULT(0)
@@ -260,10 +256,10 @@ impl IWindowsParentalControlsCore_Vtbl {
                 ::core::result::Result::Err(err) => err.into(),
             }
         }
-        unsafe extern "system" fn GetWebSettings<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControlsCore_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pcszsid: super::super::Foundation::PWSTR, ppsettings: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT {
+        unsafe extern "system" fn GetWebSettings<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControlsCore_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pcszsid: ::windows::core::PCWSTR, ppsettings: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
-            match (*this).GetWebSettings(::core::mem::transmute_copy(&pcszsid)) {
+            match (*this).GetWebSettings(::core::mem::transmute(&pcszsid)) {
                 ::core::result::Result::Ok(ok__) => {
                     *ppsettings = ::core::mem::transmute(ok__);
                     ::windows::core::HRESULT(0)
@@ -271,7 +267,7 @@ impl IWindowsParentalControlsCore_Vtbl {
                 ::core::result::Result::Err(err) => err.into(),
             }
         }
-        unsafe extern "system" fn GetWebFilterInfo<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControlsCore_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pguidid: *mut ::windows::core::GUID, ppszname: *mut super::super::Foundation::PWSTR) -> ::windows::core::HRESULT {
+        unsafe extern "system" fn GetWebFilterInfo<Identity: ::windows::core::IUnknownImpl, Impl: IWindowsParentalControlsCore_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pguidid: *mut ::windows::core::GUID, ppszname: *mut ::windows::core::PWSTR) -> ::windows::core::HRESULT {
             let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut Identity;
             let this = (*this).get_impl() as *mut Impl;
             (*this).GetWebFilterInfo(::core::mem::transmute_copy(&pguidid), ::core::mem::transmute_copy(&ppszname)).into()
