@@ -1,85 +1,85 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_ATTACH: u32 = 14u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_BREAK: u32 = 6u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_DIVOVERFLOW: u32 = 8u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_DLLSTART: u32 = 12u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_DLLSTOP: u32 = 13u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_GPFAULT: u32 = 7u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_GPFAULT2: u32 = 21u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_INIT: u32 = 20u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_INSTRFAULT: u32 = 9u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_MODFREE: u32 = 4u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_MODLOAD: u32 = 3u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_MODMOVE: u32 = 19u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_SEGFREE: u32 = 2u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_SEGLOAD: u32 = 0u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_SEGMOVE: u32 = 1u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_SINGLESTEP: u32 = 5u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_STACKFAULT: u32 = 16u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_TASKSTART: u32 = 10u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_TASKSTOP: u32 = 11u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_TEMPBP: u32 = 18u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_TOOLHELP: u32 = 15u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const DBG_WOWINIT: u32 = 17u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Threading'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`, `\"Win32_System_Threading\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Threading"))]
 pub type DEBUGEVENTPROC = ::core::option::Option<unsafe extern "system" fn(param0: *mut super::Diagnostics::Debug::DEBUG_EVENT, param1: *mut ::core::ffi::c_void) -> u32>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_ACCELERATORS: u32 = 9u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_BITMAP: u32 = 2u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_CURSOR: u32 = 12u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_CURSORCOMPONENT: u32 = 1u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_DIALOG: u32 = 5u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_ERRTABLE: u32 = 11u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_FONT: u32 = 8u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_FONTDIR: u32 = 7u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_ICON: u32 = 14u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_ICONCOMPONENT: u32 = 3u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_MAX_RESOURCE: u32 = 15u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_MENU: u32 = 4u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_NAMETABLE: u32 = 15u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_RCDATA: u32 = 10u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_STRING: u32 = 6u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GD_USERDEFINED: u32 = 0u32;
 #[repr(C, packed(4))]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct GLOBALENTRY {
     pub dwSize: u32,
@@ -122,36 +122,36 @@ impl ::core::default::Default for GLOBALENTRY {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GLOBAL_ALL: u32 = 0u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GLOBAL_FREE: u32 = 2u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GLOBAL_LRU: u32 = 1u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_BURGERMASTER: u32 = 10u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_CODE: u32 = 3u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_DATA: u32 = 2u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_DGROUP: u32 = 1u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_FREE: u32 = 7u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_INTERNAL: u32 = 8u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_MODULE: u32 = 6u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_RESOURCE: u32 = 5u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_SENTINEL: u32 = 9u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_TASK: u32 = 4u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const GT_UNKNOWN: u32 = 0u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct IMAGE_NOTE {
     pub Module: [super::super::Foundation::CHAR; 10],
@@ -191,12 +191,12 @@ impl ::core::default::Default for IMAGE_NOTE {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const MAX_MODULE_NAME: u32 = 9u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const MAX_PATH16: u32 = 255u32;
 #[repr(C, packed(4))]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct MODULEENTRY {
     pub dwSize: u32,
@@ -232,11 +232,11 @@ impl ::core::default::Default for MODULEENTRY {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type PROCESSENUMPROC = ::core::option::Option<unsafe extern "system" fn(dwprocessid: u32, dwattributes: u32, lpuserdefined: super::super::Foundation::LPARAM) -> super::super::Foundation::BOOL>;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct SEGMENT_NOTE {
     pub Selector1: u16,
@@ -279,22 +279,22 @@ impl ::core::default::Default for SEGMENT_NOTE {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const SN_CODE: u32 = 0u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const SN_DATA: u32 = 1u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const SN_V86: u32 = 2u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const STATUS_VDM_EVENT: i32 = 1073741829i32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type TASKENUMPROC = ::core::option::Option<unsafe extern "system" fn(dwthreadid: u32, hmod16: u16, htask16: u16, lpuserdefined: super::super::Foundation::LPARAM) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type TASKENUMPROCEX = ::core::option::Option<unsafe extern "system" fn(dwthreadid: u32, hmod16: u16, htask16: u16, pszmodname: *mut i8, pszfilename: *mut i8, lpuserdefined: super::super::Foundation::LPARAM) -> super::super::Foundation::BOOL>;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct TEMP_BP_NOTE {
     pub Seg: u16,
@@ -333,45 +333,45 @@ impl ::core::default::Default for TEMP_BP_NOTE {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_ALIGNMENT: u32 = 262144u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_AUXCARRY: u32 = 16u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_CARRY: u32 = 1u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_DIRECTION: u32 = 1024u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_INTERRUPT: u32 = 512u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_IOPL: u32 = 12288u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_IOPL_BITS: u32 = 18u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_OVERFLOW: u32 = 2048u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_PARITY: u32 = 4u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_RESUME: u32 = 65536u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_SIGN: u32 = 128u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_TRACE: u32 = 256u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_V86: u32 = 131072u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const V86FLAGS_ZERO: u32 = 64u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMADDR_PM16: u32 = 4u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMADDR_PM32: u32 = 16u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMADDR_V86: u32 = 2u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMBREAKTHREADPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE) -> super::super::Foundation::BOOL>;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_System_Kernel'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_System_Kernel\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 #[cfg(feature = "Win32_System_Kernel")]
 pub struct VDMCONTEXT {
@@ -467,7 +467,7 @@ impl ::core::default::Default for VDMCONTEXT {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_System_Kernel'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_System_Kernel\"`*"]
 #[cfg(feature = "Win32_System_Kernel")]
 pub struct VDMCONTEXT_WITHOUT_XSAVE {
     pub ContextFlags: u32,
@@ -552,103 +552,103 @@ impl ::core::default::Default for VDMCONTEXT_WITHOUT_XSAVE {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMCONTEXT_i386: u32 = 65536u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMCONTEXT_i486: u32 = 65536u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMDBG_BREAK_DEBUGGER: u32 = 16u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMDBG_BREAK_DIVIDEBYZERO: u32 = 256u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMDBG_BREAK_DOSTASK: u32 = 1u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMDBG_BREAK_EXCEPTIONS: u32 = 8u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMDBG_BREAK_LOADDLL: u32 = 4u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMDBG_BREAK_WOWTASK: u32 = 2u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMDBG_INITIAL_FLAGS: u32 = 256u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMDBG_MAX_SYMBOL_BUFFER: u32 = 256u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMDBG_TRACE_HISTORY: u32 = 128u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMDETECTWOWPROC = ::core::option::Option<unsafe extern "system" fn() -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMENUMPROCESSWOWPROC = ::core::option::Option<unsafe extern "system" fn(param0: PROCESSENUMPROC, param1: super::super::Foundation::LPARAM) -> i32>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMENUMTASKWOWEXPROC = ::core::option::Option<unsafe extern "system" fn(param0: u32, param1: TASKENUMPROCEX, param2: super::super::Foundation::LPARAM) -> i32>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMENUMTASKWOWPROC = ::core::option::Option<unsafe extern "system" fn(param0: u32, param1: TASKENUMPROC, param2: super::super::Foundation::LPARAM) -> i32>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMEVENT_ALLFLAGS: u32 = 57344u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMEVENT_NEEDS_INTERACTIVE: u32 = 32768u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMEVENT_PE: u32 = 8192u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMEVENT_PM16: u32 = 2u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMEVENT_V86: u32 = 1u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDMEVENT_VERBOSE: u32 = 16384u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
-pub type VDMGETADDREXPRESSIONPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::PSTR, param1: super::super::Foundation::PSTR, param2: *mut u16, param3: *mut u32, param4: *mut u16) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Kernel'*"]
+pub type VDMGETADDREXPRESSIONPROC = ::core::option::Option<unsafe extern "system" fn(param0: ::windows::core::PCSTR, param1: ::windows::core::PCSTR, param2: *mut u16, param3: *mut u32, param4: *mut u16) -> super::super::Foundation::BOOL>;
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Kernel\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Kernel"))]
+#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Kernel"))]
 pub type VDMGETCONTEXTPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: *mut VDMCONTEXT) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Kernel'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`, `\"Win32_System_Kernel\"`*"]
 #[cfg(target_arch = "x86")]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Kernel"))]
 pub type VDMGETCONTEXTPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: *mut super::Diagnostics::Debug::CONTEXT) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMGETDBGFLAGSPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE) -> u32>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
-pub type VDMGETMODULESELECTORPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: u32, param3: super::super::Foundation::PSTR, param4: *mut u16) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+pub type VDMGETMODULESELECTORPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: u32, param3: ::windows::core::PCSTR, param4: *mut u16) -> super::super::Foundation::BOOL>;
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMGETPOINTERPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: u16, param3: u32, param4: super::super::Foundation::BOOL) -> u32>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMGETSEGMENTINFOPROC = ::core::option::Option<unsafe extern "system" fn(param0: u16, param1: u32, param2: super::super::Foundation::BOOL, param3: VDM_SEGINFO) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
-pub type VDMGETSELECTORMODULEPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: u16, param3: *mut u32, param4: super::super::Foundation::PSTR, param5: u32, param6: super::super::Foundation::PSTR, param7: u32) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+pub type VDMGETSELECTORMODULEPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: u16, param3: *mut u32, param4: ::windows::core::PCSTR, param5: u32, param6: ::windows::core::PCSTR, param7: u32) -> super::super::Foundation::BOOL>;
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
-pub type VDMGETSYMBOLPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::PSTR, param1: u16, param2: u32, param3: super::super::Foundation::BOOL, param4: super::super::Foundation::BOOL, param5: super::super::Foundation::PSTR, param6: *mut u32) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug'*"]
+pub type VDMGETSYMBOLPROC = ::core::option::Option<unsafe extern "system" fn(param0: ::windows::core::PCSTR, param1: u16, param2: u32, param3: super::super::Foundation::BOOL, param4: super::super::Foundation::BOOL, param5: ::windows::core::PSTR, param6: *mut u32) -> super::super::Foundation::BOOL>;
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug"))]
+#[cfg(feature = "Win32_Foundation")]
 pub type VDMGETTHREADSELECTORENTRYPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: u32, param3: *mut VDMLDT_ENTRY) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`*"]
 #[cfg(target_arch = "x86")]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug"))]
 pub type VDMGETTHREADSELECTORENTRYPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: u32, param3: *mut super::Diagnostics::Debug::LDT_ENTRY) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Threading'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`, `\"Win32_System_Threading\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Threading"))]
 pub type VDMGLOBALFIRSTPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: *mut GLOBALENTRY, param3: u16, param4: DEBUGEVENTPROC, param5: *mut ::core::ffi::c_void) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Threading'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`, `\"Win32_System_Threading\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Threading"))]
 pub type VDMGLOBALNEXTPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: *mut GLOBALENTRY, param3: u16, param4: DEBUGEVENTPROC, param5: *mut ::core::ffi::c_void) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
-pub type VDMISMODULELOADEDPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::PSTR) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+pub type VDMISMODULELOADEDPROC = ::core::option::Option<unsafe extern "system" fn(param0: ::windows::core::PCSTR) -> super::super::Foundation::BOOL>;
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMKILLWOWPROC = ::core::option::Option<unsafe extern "system" fn() -> super::super::Foundation::BOOL>;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 pub struct VDMLDT_ENTRY {
     pub LimitLow: u16,
@@ -682,7 +682,7 @@ impl ::core::default::Default for VDMLDT_ENTRY {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 pub union VDMLDT_ENTRY_0 {
     pub Bytes: VDMLDT_ENTRY_0_1,
@@ -715,7 +715,7 @@ impl ::core::default::Default for VDMLDT_ENTRY_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 pub struct VDMLDT_ENTRY_0_0 {
     pub _bitfield: u32,
@@ -753,7 +753,7 @@ impl ::core::default::Default for VDMLDT_ENTRY_0_0 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 pub struct VDMLDT_ENTRY_0_1 {
     pub BaseMid: u8,
@@ -793,38 +793,38 @@ impl ::core::default::Default for VDMLDT_ENTRY_0_1 {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Threading'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`, `\"Win32_System_Threading\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Threading"))]
 pub type VDMMODULEFIRSTPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: *mut MODULEENTRY, param3: DEBUGEVENTPROC, param4: *mut ::core::ffi::c_void) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Threading'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`, `\"Win32_System_Threading\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Threading"))]
 pub type VDMMODULENEXTPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: *mut MODULEENTRY, param3: DEBUGEVENTPROC, param4: *mut ::core::ffi::c_void) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Threading'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`, `\"Win32_System_Threading\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Threading"))]
 pub type VDMPROCESSEXCEPTIONPROC = ::core::option::Option<unsafe extern "system" fn(param0: *mut super::Diagnostics::Debug::DEBUG_EVENT) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Kernel'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Kernel\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Kernel"))]
+#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Kernel"))]
 pub type VDMSETCONTEXTPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: *mut VDMCONTEXT) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation', 'Win32_System_Diagnostics_Debug', 'Win32_System_Kernel'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`, `\"Win32_System_Diagnostics_Debug\"`, `\"Win32_System_Kernel\"`*"]
 #[cfg(target_arch = "x86")]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Diagnostics_Debug", feature = "Win32_System_Kernel"))]
 pub type VDMSETCONTEXTPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: super::super::Foundation::HANDLE, param2: *mut super::Diagnostics::Debug::CONTEXT) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMSETDBGFLAGSPROC = ::core::option::Option<unsafe extern "system" fn(param0: super::super::Foundation::HANDLE, param1: u32) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
-pub type VDMSTARTTASKINWOWPROC = ::core::option::Option<unsafe extern "system" fn(param0: u32, param1: super::super::Foundation::PSTR, param2: u16) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+pub type VDMSTARTTASKINWOWPROC = ::core::option::Option<unsafe extern "system" fn(param0: u32, param1: ::windows::core::PCSTR, param2: u16) -> super::super::Foundation::BOOL>;
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub type VDMTERMINATETASKINWOWPROC = ::core::option::Option<unsafe extern "system" fn(param0: u32, param1: u16) -> super::super::Foundation::BOOL>;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDM_KGDT_R3_CODE: u32 = 24u32;
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`*"]
 pub const VDM_MAXIMUM_SUPPORTED_EXTENSION: u32 = 512u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_VirtualDosMachines', 'Win32_Foundation'*"]
+#[doc = "*Required features: `\"Win32_System_VirtualDosMachines\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 pub struct VDM_SEGINFO {
     pub Selector: u16,
