@@ -1,17 +1,17 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HANDLE_ACCESS_OPTIONS(pub u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HAO_NONE: HANDLE_ACCESS_OPTIONS = HANDLE_ACCESS_OPTIONS(0u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HAO_READ_ATTRIBUTES: HANDLE_ACCESS_OPTIONS = HANDLE_ACCESS_OPTIONS(128u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HAO_READ: HANDLE_ACCESS_OPTIONS = HANDLE_ACCESS_OPTIONS(1179785u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HAO_WRITE: HANDLE_ACCESS_OPTIONS = HANDLE_ACCESS_OPTIONS(1179926u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HAO_DELETE: HANDLE_ACCESS_OPTIONS = HANDLE_ACCESS_OPTIONS(65536u32);
 impl ::core::marker::Copy for HANDLE_ACCESS_OPTIONS {}
 impl ::core::clone::Clone for HANDLE_ACCESS_OPTIONS {
@@ -60,19 +60,19 @@ impl ::core::ops::Not for HANDLE_ACCESS_OPTIONS {
         Self(self.0.not())
     }
 }
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HANDLE_CREATION_OPTIONS(pub i32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HCO_CREATE_NEW: HANDLE_CREATION_OPTIONS = HANDLE_CREATION_OPTIONS(1i32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HCO_CREATE_ALWAYS: HANDLE_CREATION_OPTIONS = HANDLE_CREATION_OPTIONS(2i32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HCO_OPEN_EXISTING: HANDLE_CREATION_OPTIONS = HANDLE_CREATION_OPTIONS(3i32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HCO_OPEN_ALWAYS: HANDLE_CREATION_OPTIONS = HANDLE_CREATION_OPTIONS(4i32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HCO_TRUNCATE_EXISTING: HANDLE_CREATION_OPTIONS = HANDLE_CREATION_OPTIONS(5i32);
 impl ::core::marker::Copy for HANDLE_CREATION_OPTIONS {}
 impl ::core::clone::Clone for HANDLE_CREATION_OPTIONS {
@@ -93,25 +93,25 @@ impl ::core::fmt::Debug for HANDLE_CREATION_OPTIONS {
         f.debug_tuple("HANDLE_CREATION_OPTIONS").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HANDLE_OPTIONS(pub u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HO_NONE: HANDLE_OPTIONS = HANDLE_OPTIONS(0u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HO_OPEN_REQUIRING_OPLOCK: HANDLE_OPTIONS = HANDLE_OPTIONS(262144u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HO_DELETE_ON_CLOSE: HANDLE_OPTIONS = HANDLE_OPTIONS(67108864u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HO_SEQUENTIAL_SCAN: HANDLE_OPTIONS = HANDLE_OPTIONS(134217728u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HO_RANDOM_ACCESS: HANDLE_OPTIONS = HANDLE_OPTIONS(268435456u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HO_NO_BUFFERING: HANDLE_OPTIONS = HANDLE_OPTIONS(536870912u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HO_OVERLAPPED: HANDLE_OPTIONS = HANDLE_OPTIONS(1073741824u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HO_WRITE_THROUGH: HANDLE_OPTIONS = HANDLE_OPTIONS(2147483648u32);
 impl ::core::marker::Copy for HANDLE_OPTIONS {}
 impl ::core::clone::Clone for HANDLE_OPTIONS {
@@ -160,17 +160,17 @@ impl ::core::ops::Not for HANDLE_OPTIONS {
         Self(self.0.not())
     }
 }
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 #[repr(transparent)]
 #[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HANDLE_SHARING_OPTIONS(pub u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HSO_SHARE_NONE: HANDLE_SHARING_OPTIONS = HANDLE_SHARING_OPTIONS(0u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HSO_SHARE_READ: HANDLE_SHARING_OPTIONS = HANDLE_SHARING_OPTIONS(1u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HSO_SHARE_WRITE: HANDLE_SHARING_OPTIONS = HANDLE_SHARING_OPTIONS(2u32);
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 pub const HSO_SHARE_DELETE: HANDLE_SHARING_OPTIONS = HANDLE_SHARING_OPTIONS(4u32);
 impl ::core::marker::Copy for HANDLE_SHARING_OPTIONS {}
 impl ::core::clone::Clone for HANDLE_SHARING_OPTIONS {
@@ -219,11 +219,11 @@ impl ::core::ops::Not for HANDLE_SHARING_OPTIONS {
         Self(self.0.not())
     }
 }
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 #[repr(transparent)]
 pub struct IOplockBreakingHandler(::windows::core::IUnknown);
 impl IOplockBreakingHandler {
-    #[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+    #[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
     pub unsafe fn OplockBreaking(&self) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).OplockBreaking)(::core::mem::transmute_copy(self)).ok()
     }
@@ -243,7 +243,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IOplockBr
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IOplockBreakingHandler {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IOplockBreakingHandler {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -274,11 +274,11 @@ pub struct IOplockBreakingHandler_Vtbl {
     pub base: ::windows::core::IUnknownVtbl,
     pub OplockBreaking: unsafe extern "system" fn(this: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 #[repr(transparent)]
 pub struct IRandomAccessStreamFileAccessMode(::windows::core::IUnknown);
 impl IRandomAccessStreamFileAccessMode {
-    #[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+    #[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
     pub unsafe fn GetMode(&self) -> ::windows::core::Result<u32> {
         let mut result__: u32 = ::core::mem::zeroed();
         (::windows::core::Interface::vtable(self).GetMode)(::core::mem::transmute_copy(self), ::core::mem::transmute(&mut result__)).from_abi::<u32>(result__)
@@ -299,7 +299,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IRandomAc
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IRandomAccessStreamFileAccessMode {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IRandomAccessStreamFileAccessMode {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -330,13 +330,13 @@ pub struct IRandomAccessStreamFileAccessMode_Vtbl {
     pub base: ::windows::core::IUnknownVtbl,
     pub GetMode: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, fileaccessmode: *mut u32) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 #[repr(transparent)]
 pub struct IStorageFolderHandleAccess(::windows::core::IUnknown);
 impl IStorageFolderHandleAccess {
-    #[doc = "*Required features: 'Win32_System_WinRT_Storage', 'Win32_Foundation'*"]
+    #[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`, `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
-    pub unsafe fn Create<'a, Param0: ::windows::core::IntoParam<'a, super::super::super::Foundation::PWSTR>, Param5: ::windows::core::IntoParam<'a, IOplockBreakingHandler>>(&self, filename: Param0, creationoptions: HANDLE_CREATION_OPTIONS, accessoptions: HANDLE_ACCESS_OPTIONS, sharingoptions: HANDLE_SHARING_OPTIONS, options: HANDLE_OPTIONS, oplockbreakinghandler: Param5) -> ::windows::core::Result<super::super::super::Foundation::HANDLE> {
+    pub unsafe fn Create<'a, Param0: ::windows::core::IntoParam<'a, ::windows::core::PCWSTR>, Param5: ::windows::core::IntoParam<'a, IOplockBreakingHandler>>(&self, filename: Param0, creationoptions: HANDLE_CREATION_OPTIONS, accessoptions: HANDLE_ACCESS_OPTIONS, sharingoptions: HANDLE_SHARING_OPTIONS, options: HANDLE_OPTIONS, oplockbreakinghandler: Param5) -> ::windows::core::Result<super::super::super::Foundation::HANDLE> {
         let mut result__: super::super::super::Foundation::HANDLE = ::core::mem::zeroed();
         (::windows::core::Interface::vtable(self).Create)(::core::mem::transmute_copy(self), filename.into_param().abi(), ::core::mem::transmute(creationoptions), ::core::mem::transmute(accessoptions), ::core::mem::transmute(sharingoptions), ::core::mem::transmute(options), oplockbreakinghandler.into_param().abi(), ::core::mem::transmute(&mut result__)).from_abi::<super::super::super::Foundation::HANDLE>(result__)
     }
@@ -356,7 +356,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IStorageF
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IStorageFolderHandleAccess {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IStorageFolderHandleAccess {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -386,15 +386,15 @@ unsafe impl ::windows::core::Interface for IStorageFolderHandleAccess {
 pub struct IStorageFolderHandleAccess_Vtbl {
     pub base: ::windows::core::IUnknownVtbl,
     #[cfg(feature = "Win32_Foundation")]
-    pub Create: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, filename: super::super::super::Foundation::PWSTR, creationoptions: HANDLE_CREATION_OPTIONS, accessoptions: HANDLE_ACCESS_OPTIONS, sharingoptions: HANDLE_SHARING_OPTIONS, options: HANDLE_OPTIONS, oplockbreakinghandler: ::windows::core::RawPtr, interophandle: *mut super::super::super::Foundation::HANDLE) -> ::windows::core::HRESULT,
+    pub Create: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, filename: ::windows::core::PCWSTR, creationoptions: HANDLE_CREATION_OPTIONS, accessoptions: HANDLE_ACCESS_OPTIONS, sharingoptions: HANDLE_SHARING_OPTIONS, options: HANDLE_OPTIONS, oplockbreakinghandler: ::windows::core::RawPtr, interophandle: *mut super::super::super::Foundation::HANDLE) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Win32_Foundation"))]
     Create: usize,
 }
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 #[repr(transparent)]
 pub struct IStorageItemHandleAccess(::windows::core::IUnknown);
 impl IStorageItemHandleAccess {
-    #[doc = "*Required features: 'Win32_System_WinRT_Storage', 'Win32_Foundation'*"]
+    #[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`, `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
     pub unsafe fn Create<'a, Param3: ::windows::core::IntoParam<'a, IOplockBreakingHandler>>(&self, accessoptions: HANDLE_ACCESS_OPTIONS, sharingoptions: HANDLE_SHARING_OPTIONS, options: HANDLE_OPTIONS, oplockbreakinghandler: Param3) -> ::windows::core::Result<super::super::super::Foundation::HANDLE> {
         let mut result__: super::super::super::Foundation::HANDLE = ::core::mem::zeroed();
@@ -416,7 +416,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IStorageI
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IStorageItemHandleAccess {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IStorageItemHandleAccess {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -450,11 +450,11 @@ pub struct IStorageItemHandleAccess_Vtbl {
     #[cfg(not(feature = "Win32_Foundation"))]
     Create: usize,
 }
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 #[repr(transparent)]
 pub struct IUnbufferedFileHandleOplockCallback(::windows::core::IUnknown);
 impl IUnbufferedFileHandleOplockCallback {
-    #[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+    #[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
     pub unsafe fn OnBrokenCallback(&self) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).OnBrokenCallback)(::core::mem::transmute_copy(self)).ok()
     }
@@ -474,7 +474,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IUnbuffer
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IUnbufferedFileHandleOplockCallback {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IUnbufferedFileHandleOplockCallback {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
@@ -505,16 +505,16 @@ pub struct IUnbufferedFileHandleOplockCallback_Vtbl {
     pub base: ::windows::core::IUnknownVtbl,
     pub OnBrokenCallback: unsafe extern "system" fn(this: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
-#[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+#[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
 #[repr(transparent)]
 pub struct IUnbufferedFileHandleProvider(::windows::core::IUnknown);
 impl IUnbufferedFileHandleProvider {
-    #[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+    #[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
     pub unsafe fn OpenUnbufferedFileHandle<'a, Param0: ::windows::core::IntoParam<'a, IUnbufferedFileHandleOplockCallback>>(&self, oplockbreakcallback: Param0) -> ::windows::core::Result<usize> {
         let mut result__: usize = ::core::mem::zeroed();
         (::windows::core::Interface::vtable(self).OpenUnbufferedFileHandle)(::core::mem::transmute_copy(self), oplockbreakcallback.into_param().abi(), ::core::mem::transmute(&mut result__)).from_abi::<usize>(result__)
     }
-    #[doc = "*Required features: 'Win32_System_WinRT_Storage'*"]
+    #[doc = "*Required features: `\"Win32_System_WinRT_Storage\"`*"]
     pub unsafe fn CloseUnbufferedFileHandle(&self) -> ::windows::core::Result<()> {
         (::windows::core::Interface::vtable(self).CloseUnbufferedFileHandle)(::core::mem::transmute_copy(self)).ok()
     }
@@ -534,7 +534,7 @@ impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for IUnbuffer
         ::windows::core::Param::Owned(unsafe { ::core::mem::transmute(self) })
     }
 }
-impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &IUnbufferedFileHandleProvider {
+impl<'a> ::windows::core::IntoParam<'a, ::windows::core::IUnknown> for &'a IUnbufferedFileHandleProvider {
     fn into_param(self) -> ::windows::core::Param<'a, ::windows::core::IUnknown> {
         ::windows::core::Param::Borrowed(unsafe { ::core::mem::transmute(self) })
     }
